@@ -1,18 +1,14 @@
 from __future__ import annotations
 
 import os
+import warnings
+from collections.abc import Iterable, Iterator
 from copy import deepcopy
-from html import escape
+from itertools import chain
 from typing import (
     TYPE_CHECKING,
     Any,
     Callable,
-    Dict,
-    Iterable,
-    List,
-    Optional,
-    Tuple,
-    Type,
     TypeVar,
     Union,
     cast,
@@ -21,7 +17,6 @@ from typing import (
 import pystac
 from pystac.cache import ResolvedObjectCache
 from pystac.errors import STACTypeError
-from pystac.html.jinja_env import get_jinja_env
 from pystac.layout import (
     BestPracticesLayoutStrategy,
     HrefLayoutStrategy,
@@ -35,6 +30,7 @@ from pystac.serialization import (
 )
 from pystac.stac_object import STACObject, STACObjectType
 from pystac.utils import (
+    HREF,
     StringEnum,
     is_absolute_href,
     make_absolute_href,
@@ -44,6 +40,7 @@ from pystac.utils import (
 if TYPE_CHECKING:
     from pystac.asset import Asset
     from pystac.collection import Collection
+    from pystac.extensions.ext import CatalogExt
     from pystac.item import Item
 
 C = TypeVar("C", bound="Catalog")
@@ -81,7 +78,7 @@ class CatalogType(StringEnum):
     """
 
     @classmethod
-    def determine_type(cls, stac_json: Dict[str, Any]) -> Optional[CatalogType]:
+    def determine_type(cls, stac_json: dict[str, Any]) -> CatalogType | None:
         """Determines the catalog type based on a STAC JSON dict.
 
         Only applies to Catalogs or Collections
@@ -139,27 +136,27 @@ class Catalog(STACObject):
     description: str
     """Detailed multi-line description to fully explain the catalog."""
 
-    extra_fields: Dict[str, Any]
+    extra_fields: dict[str, Any]
     """Extra fields that are part of the top-level JSON properties of the Catalog."""
 
     id: str
     """Identifier for the catalog."""
 
-    links: List[Link]
+    links: list[Link]
     """A list of :class:`~pystac.Link` objects representing all links associated with
     this Catalog."""
 
-    title: Optional[str]
+    title: str | None
     """Optional short descriptive one-line title for the catalog."""
 
-    stac_extensions: List[str]
+    stac_extensions: list[str]
     """List of extensions the Catalog implements."""
 
     _resolved_objects: ResolvedObjectCache
 
     STAC_OBJECT_TYPE = pystac.STACObjectType.CATALOG
 
-    _stac_io: Optional[pystac.StacIO] = None
+    _stac_io: pystac.StacIO | None = None
     """Optional instance of StacIO that will be used by default
     for any IO operations on objects contained by this catalog.
     Set while reading in a catalog. This is set when a catalog
@@ -174,10 +171,10 @@ class Catalog(STACObject):
         self,
         id: str,
         description: str,
-        title: Optional[str] = None,
-        stac_extensions: Optional[List[str]] = None,
-        extra_fields: Optional[Dict[str, Any]] = None,
-        href: Optional[str] = None,
+        title: str | None = None,
+        stac_extensions: list[str] | None = None,
+        extra_fields: dict[str, Any] | None = None,
+        href: str | None = None,
         catalog_type: CatalogType = CatalogType.ABSOLUTE_PUBLISHED,
     ):
         super().__init__(stac_extensions or [])
@@ -202,17 +199,9 @@ class Catalog(STACObject):
         self._resolved_objects.cache(self)
 
     def __repr__(self) -> str:
-        return "<Catalog id={}>".format(self.id)
+        return f"<Catalog id={self.id}>"
 
-    def _repr_html_(self) -> str:
-        jinja_env = get_jinja_env()
-        if jinja_env:
-            template = jinja_env.get_template("Catalog.jinja2")
-            return str(template.render(catalog=self))
-        else:
-            return escape(repr(self))
-
-    def set_root(self, root: Optional["Catalog"]) -> None:
+    def set_root(self, root: Catalog | None) -> None:
         STACObject.set_root(self, root)
         if root is not None:
             root._resolved_objects = ResolvedObjectCache.merge(
@@ -234,13 +223,18 @@ class Catalog(STACObject):
 
     def add_child(
         self,
-        child: Union["Catalog", Collection],
-        title: Optional[str] = None,
-        strategy: Optional[HrefLayoutStrategy] = None,
-    ) -> None:
+        child: Catalog | Collection,
+        title: str | None = None,
+        strategy: HrefLayoutStrategy | None = None,
+        set_parent: bool = True,
+    ) -> Link:
         """Adds a link to a child :class:`~pystac.Catalog` or
-        :class:`~pystac.Collection`. This method will set the child's parent to this
-        object, and its root to this Catalog's root.
+        :class:`~pystac.Collection`.
+
+        This method will set the child's parent to this object and potentially
+        override its self_link (unless ``set_parent`` is False).
+
+        It will always set its root to this Catalog's root.
 
         Args:
             child : The child to add.
@@ -248,6 +242,11 @@ class Catalog(STACObject):
             strategy : The layout strategy to use for setting the
                 self href of the child. If not provided, defaults to
                 :class:`~pystac.layout.BestPracticesLayoutStrategy`.
+            set_parent : Whether to set the parent on the child as well.
+                Defaults to True.
+
+        Returns:
+            Link: The link created for the child
         """
 
         # Prevent typo confusion
@@ -258,36 +257,47 @@ class Catalog(STACObject):
             strategy = BestPracticesLayoutStrategy()
 
         child.set_root(self.get_root())
-        child.set_parent(self)
+        if set_parent:
+            child.set_parent(self)
+        else:
+            child._allow_parent_to_override_href = False
 
         # set self link
         self_href = self.get_self_href()
-        if self_href:
+        if self_href and set_parent:
             child_href = strategy.get_href(child, os.path.dirname(self_href))
             child.set_self_href(child_href)
 
-        self.add_link(Link.child(child, title=title))
+        child_link = Link.child(child, title=title)
+        self.add_link(child_link)
+        return child_link
 
-    def add_children(self, children: Iterable[Union["Catalog", Collection]]) -> None:
+    def add_children(self, children: Iterable[Catalog | Collection]) -> list[Link]:
         """Adds links to multiple :class:`~pystac.Catalog` or `~pystac.Collection`
         objects. This method will set each child's parent to this object, and their
         root to this Catalog's root.
 
         Args:
             children : The children to add.
+
+        Returns:
+            List[Link]: An array of links created for the children
         """
-        for child in children:
-            self.add_child(child)
+        return [self.add_child(child) for child in children]
 
     def add_item(
         self,
         item: Item,
-        title: Optional[str] = None,
-        strategy: Optional[HrefLayoutStrategy] = None,
-    ) -> None:
+        title: str | None = None,
+        strategy: HrefLayoutStrategy | None = None,
+        set_parent: bool = True,
+    ) -> Link:
         """Adds a link to an :class:`~pystac.Item`.
-        This method will set the item's parent to this object, and its root to
-        this Catalog's root.
+
+        This method will set the item's parent to this object and potentially
+        override its self_link (unless ``set_parent`` is False)
+
+        It will always set its root to this Catalog's root.
 
         Args:
             item : The item to add.
@@ -295,6 +305,11 @@ class Catalog(STACObject):
             strategy : The layout strategy to use for setting the
                 self href of the item. If not provided, defaults to
                 :class:`~pystac.layout.BestPracticesLayoutStrategy`.
+            set_parent : Whether to set the parent on the item as well.
+                Defaults to True.
+
+        Returns:
+            Link: The link created for the item
         """
 
         # Prevent typo confusion
@@ -305,21 +320,26 @@ class Catalog(STACObject):
             strategy = BestPracticesLayoutStrategy()
 
         item.set_root(self.get_root())
-        item.set_parent(self)
+        if set_parent:
+            item.set_parent(self)
+        else:
+            item._allow_parent_to_override_href = False
 
         # set self link
         self_href = self.get_self_href()
-        if self_href:
+        if self_href and set_parent:
             item_href = strategy.get_href(item, os.path.dirname(self_href))
             item.set_self_href(item_href)
 
-        self.add_link(Link.item(item, title=title))
+        item_link = Link.item(item, title=title)
+        self.add_link(item_link)
+        return item_link
 
     def add_items(
         self,
         items: Iterable[Item],
-        strategy: Optional[HrefLayoutStrategy] = None,
-    ) -> None:
+        strategy: HrefLayoutStrategy | None = None,
+    ) -> list[Link]:
         """Adds links to multiple :class:`Items <pystac.Item>`.
 
         This method will set each item's parent to this object, and their root to
@@ -330,13 +350,15 @@ class Catalog(STACObject):
             strategy : The layout strategy to use for setting the
                 self href of the items. If not provided, defaults to
                 :class:`~pystac.layout.BestPracticesLayoutStrategy`.
+
+        Returns:
+            List[Link]: A list of links created for the item
         """
-        for item in items:
-            self.add_item(item, strategy=strategy)
+        return [self.add_item(item, strategy=strategy) for item in items]
 
     def get_child(
-        self, id: str, recursive: bool = False
-    ) -> Optional[Union["Catalog", Collection]]:
+        self, id: str, recursive: bool = False, sort_links_by_id: bool = True
+    ) -> Catalog | Collection | None:
         """Gets the child of this catalog with the given ID, if it exists.
 
         Args:
@@ -344,13 +366,33 @@ class Catalog(STACObject):
             recursive : If True, search this catalog and all children for the
                 item; otherwise, only search the children of this catalog. Defaults
                 to False.
+            sort_links_by_id : If True, links containing the ID will be checked
+                first. If links do not contain the ID then setting this to False
+                will improve performance. Defaults to True.
 
         Return:
             Optional Catalog or Collection: The child with the given ID,
             or None if not found.
         """
         if not recursive:
-            return next((c for c in self.get_children() if c.id == id), None)
+            children: Iterable[pystac.Catalog | pystac.Collection]
+            if not sort_links_by_id:
+                children = self.get_children()
+            else:
+
+                def sort_function(links: list[Link]) -> list[Link]:
+                    return sorted(
+                        links,
+                        key=lambda x: (href := x.get_href()) is None or id not in href,
+                    )
+
+                children = map(
+                    lambda x: cast(Union[pystac.Catalog, pystac.Collection], x),
+                    self.get_stac_objects(
+                        pystac.RelType.CHILD, modify_links=sort_function
+                    ),
+                )
+            return next((c for c in children if c.id == id), None)
         else:
             for root, _, _ in self.walk():
                 child = root.get_child(id, recursive=False)
@@ -358,7 +400,7 @@ class Catalog(STACObject):
                     return child
             return None
 
-    def get_children(self) -> Iterable[Union["Catalog", Collection]]:
+    def get_children(self) -> Iterable[Catalog | Collection]:
         """Return all children of this catalog.
 
         Return:
@@ -385,7 +427,7 @@ class Catalog(STACObject):
         for child in self.get_children():
             yield from child.get_collections()
 
-    def get_child_links(self) -> List[Link]:
+    def get_child_links(self) -> list[Link]:
         """Return all child links of this catalog.
 
         Return:
@@ -409,7 +451,7 @@ class Catalog(STACObject):
         Args:
             child_id : The ID of the child to remove.
         """
-        new_links: List[pystac.Link] = []
+        new_links: list[pystac.Link] = []
         root = self.get_root()
         for link in self.links:
             if link.rel != pystac.RelType.CHILD:
@@ -424,8 +466,14 @@ class Catalog(STACObject):
                     child.set_root(None)
         self.links = new_links
 
-    def get_item(self, id: str, recursive: bool = False) -> Optional[Item]:
-        """Returns an item with a given ID.
+    def get_item(self, id: str, recursive: bool = False) -> Item | None:
+        """
+        DEPRECATED.
+
+        .. deprecated:: 1.8
+            Use :meth:`next(pystac.Catalog.get_items(id), None)` instead.
+
+        Returns an item with a given ID.
 
         Args:
             id : The ID of the item to find.
@@ -436,6 +484,11 @@ class Catalog(STACObject):
         Return:
             Item or None: The item with the given ID, or None if not found.
         """
+        warnings.warn(
+            "get_item is deprecated and will be removed in v2. "
+            "Use next(self.get_items(id), None) instead",
+            DeprecationWarning,
+        )
         if not recursive:
             return next((i for i in self.get_items() if i.id == id), None)
         else:
@@ -445,15 +498,35 @@ class Catalog(STACObject):
                     return item
             return None
 
-    def get_items(self) -> Iterable[Item]:
-        """Return all items of this catalog.
+    def get_items(self, *ids: str, recursive: bool = False) -> Iterator[Item]:
+        """Return all items or specific items of this catalog.
+
+        Args:
+            *ids : The IDs of the items to include.
+            recursive : If True, search this catalog and all children for the
+                item; otherwise, only search the items of this catalog. Defaults
+                to False.
 
         Return:
-            Iterable[Item]: Generator of items whose parent is this catalog.
+            Iterator[Item]: Generator of items whose parent is this catalog, and
+                (if recursive) all catalogs or collections connected to this catalog
+                through child links.
         """
-        return map(
-            lambda x: cast(pystac.Item, x), self.get_stac_objects(pystac.RelType.ITEM)
-        )
+        items: Iterator[Item]
+        if not recursive:
+            items = map(
+                lambda x: cast(pystac.Item, x),
+                self.get_stac_objects(pystac.RelType.ITEM),
+            )
+        else:
+            items = chain(
+                self.get_items(recursive=False),
+                *(child.get_items(recursive=True) for child in self.get_children()),
+            )
+        if ids:
+            yield from (i for i in items if i.id in ids)
+        else:
+            yield from items
 
     def clear_items(self) -> None:
         """Removes all items from this catalog.
@@ -475,7 +548,7 @@ class Catalog(STACObject):
         Args:
             item_id : The ID of the item to remove.
         """
-        new_links: List[pystac.Link] = []
+        new_links: list[pystac.Link] = []
         root = self.get_root()
         for link in self.links:
             if link.rel != pystac.RelType.ITEM:
@@ -490,8 +563,14 @@ class Catalog(STACObject):
                     item.set_root(None)
         self.links = new_links
 
-    def get_all_items(self) -> Iterable[Item]:
-        """Get all items from this catalog and all subcatalogs. Will traverse
+    def get_all_items(self) -> Iterator[Item]:
+        """
+        DEPRECATED.
+
+        .. deprecated:: 1.8
+            Use :meth:`pystac.Catalog.get_items(recursive=True)` instead.
+
+        Get all items from this catalog and all subcatalogs. Will traverse
         any subcatalogs recursively.
 
         Returns:
@@ -499,11 +578,16 @@ class Catalog(STACObject):
                 catalogs or collections connected to this catalog through
                 child links.
         """
-        yield from self.get_items()
-        for child in self.get_children():
-            yield from child.get_all_items()
+        warnings.warn(
+            "get_all_items is deprecated and will be removed in v2",
+            DeprecationWarning,
+        )
+        return chain(
+            self.get_items(),
+            *(child.get_items(recursive=True) for child in self.get_children()),
+        )
 
-    def get_item_links(self) -> List[Link]:
+    def get_item_links(self) -> list[Link]:
         """Return all item links of this catalog.
 
         Return:
@@ -513,7 +597,7 @@ class Catalog(STACObject):
 
     def to_dict(
         self, include_self_link: bool = True, transform_hrefs: bool = True
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         links = [
             x
             for x in self.links
@@ -522,7 +606,7 @@ class Catalog(STACObject):
         if not include_self_link:
             links = [x for x in links if x.rel != pystac.RelType.SELF]
 
-        d: Dict[str, Any] = {
+        d: dict[str, Any] = {
             "type": self.STAC_OBJECT_TYPE.value.title(),
             "id": self.id,
             "stac_version": pystac.get_stac_version(),
@@ -567,27 +651,25 @@ class Catalog(STACObject):
         return clone
 
     def make_all_asset_hrefs_relative(self) -> None:
-        """Makes all the HREFs of assets belonging to items in this catalog
-        and all children to be relative, recursively.
-        """
-        for _, _, items in self.walk():
-            for item in items:
-                item.make_asset_hrefs_relative()
+        """Recursively makes all the HREFs of assets in this catalog relative"""
+        for item in self.get_items(recursive=True):
+            item.make_asset_hrefs_relative()
+        for collection in self.get_all_collections():
+            collection.make_asset_hrefs_relative()
 
     def make_all_asset_hrefs_absolute(self) -> None:
-        """Makes all the HREFs of assets belonging to items in this catalog
-        and all children to be absolute, recursively.
-        """
-        for _, _, items in self.walk():
-            for item in items:
-                item.make_asset_hrefs_absolute()
+        """Recursively makes all the HREFs of assets in this catalog absolute"""
+        for item in self.get_items(recursive=True):
+            item.make_asset_hrefs_absolute()
+        for collection in self.get_all_collections():
+            collection.make_asset_hrefs_absolute()
 
     def normalize_and_save(
         self,
         root_href: str,
-        catalog_type: Optional[CatalogType] = None,
-        strategy: Optional[HrefLayoutStrategy] = None,
-        stac_io: Optional[pystac.StacIO] = None,
+        catalog_type: CatalogType | None = None,
+        strategy: HrefLayoutStrategy | None = None,
+        stac_io: pystac.StacIO | None = None,
         skip_unresolved: bool = False,
     ) -> None:
         """Normalizes link HREFs to the given root_href, and saves the catalog.
@@ -622,7 +704,7 @@ class Catalog(STACObject):
     def normalize_hrefs(
         self,
         root_href: str,
-        strategy: Optional[HrefLayoutStrategy] = None,
+        strategy: HrefLayoutStrategy | None = None,
         skip_unresolved: bool = False,
     ) -> None:
         """Normalize HREFs will regenerate all link HREFs based on
@@ -656,10 +738,17 @@ class Catalog(STACObject):
         if not is_absolute_href(root_href):
             root_href = make_absolute_href(root_href, os.getcwd(), start_is_dir=True)
 
-        def process_item(item: Item, _root_href: str) -> Callable[[], None]:
+        def process_item(
+            item: Item, _root_href: str, parent: Catalog | None
+        ) -> Callable[[], None] | None:
             if not skip_unresolved:
                 item.resolve_links()
 
+            # Abort as the intended parent is not the actual parent
+            # https://github.com/stac-utils/pystac/issues/1116
+            if parent is not None and item.get_parent() != parent:
+                return None
+
             new_self_href = _strategy.get_href(item, _root_href)
 
             def fn() -> None:
@@ -668,13 +757,21 @@ class Catalog(STACObject):
             return fn
 
         def process_catalog(
-            cat: Catalog, _root_href: str, is_root: bool
-        ) -> List[Callable[[], None]]:
-            setter_funcs: List[Callable[[], None]] = []
+            cat: Catalog,
+            _root_href: str,
+            is_root: bool,
+            parent: Catalog | None = None,
+        ) -> list[Callable[[], None]]:
+            setter_funcs: list[Callable[[], None]] = []
 
             if not skip_unresolved:
                 cat.resolve_links()
 
+            # Abort as the intended parent is not the actual parent
+            # https://github.com/stac-utils/pystac/issues/1116
+            if parent is not None and cat.get_parent() != parent:
+                return setter_funcs
+
             new_self_href = _strategy.get_href(cat, _root_href, is_root)
             new_root = os.path.dirname(new_self_href)
 
@@ -683,9 +780,11 @@ class Catalog(STACObject):
                     continue
                 elif link.rel == pystac.RelType.ITEM:
                     link.resolve_stac_object(root=self.get_root())
-                    setter_funcs.append(
-                        process_item(cast(pystac.Item, link.target), new_root)
+                    item_fn = process_item(
+                        cast(pystac.Item, link.target), new_root, cat
                     )
+                    if item_fn is not None:
+                        setter_funcs.append(item_fn)
                 elif link.rel == pystac.RelType.CHILD:
                     link.resolve_stac_object(root=self.get_root())
                     setter_funcs.extend(
@@ -693,6 +792,7 @@ class Catalog(STACObject):
                             cast(Union[pystac.Catalog, pystac.Collection], link.target),
                             new_root,
                             is_root=False,
+                            parent=cat,
                         )
                     )
 
@@ -714,9 +814,9 @@ class Catalog(STACObject):
     def generate_subcatalogs(
         self,
         template: str,
-        defaults: Optional[Dict[str, Any]] = None,
-        parent_ids: Optional[List[str]] = None,
-    ) -> List["Catalog"]:
+        defaults: dict[str, Any] | None = None,
+        parent_ids: list[str] | None = None,
+    ) -> list[Catalog]:
         """Walks through the catalog and generates subcatalogs
         for items based on the template string.
 
@@ -738,7 +838,7 @@ class Catalog(STACObject):
         Returns:
             [catalog]: List of new catalogs created
         """
-        result: List[Catalog] = []
+        result: list[Catalog] = []
         parent_ids = parent_ids or list()
         parent_ids.append(self.id)
         for child in self.get_children():
@@ -750,16 +850,14 @@ class Catalog(STACObject):
 
         layout_template = LayoutTemplate(template, defaults=defaults)
 
-        keep_item_links: List[Link] = []
+        keep_item_links: list[Link] = []
         item_links = [lk for lk in self.links if lk.rel == pystac.RelType.ITEM]
         for link in item_links:
             link.resolve_stac_object(root=self.get_root())
             item = cast(pystac.Item, link.target)
             subcat_ids = layout_template.substitute(item).split("/")
             id_iter = reversed(parent_ids)
-            if all(
-                ["{}".format(id) == next(id_iter, None) for id in reversed(subcat_ids)]
-            ):
+            if all([f"{id}" == next(id_iter, None) for id in reversed(subcat_ids)]):
                 # Skip items for which the sub-catalog structure already
                 # matches the template. The list of parent IDs can include more
                 # elements on the root side, so compare the reversed sequences.
@@ -793,9 +891,9 @@ class Catalog(STACObject):
 
     def save(
         self,
-        catalog_type: Optional[CatalogType] = None,
-        dest_href: Optional[str] = None,
-        stac_io: Optional[pystac.StacIO] = None,
+        catalog_type: CatalogType | None = None,
+        dest_href: str | None = None,
+        stac_io: pystac.StacIO | None = None,
     ) -> None:
         """Save this catalog and all it's children/item to files determined by the
         object's self link HREF or a specified path.
@@ -889,7 +987,7 @@ class Catalog(STACObject):
 
     def walk(
         self,
-    ) -> Iterable[Tuple["Catalog", Iterable["Catalog"], Iterable[Item]]]:
+    ) -> Iterable[tuple[Catalog, Iterable[Catalog], Iterable[Item]]]:
         """Walks through children and items of catalogs.
 
         For each catalog in the STAC's tree rooted at this catalog (including this
@@ -925,23 +1023,41 @@ class Catalog(STACObject):
             for item in items:
                 pass
 
-    def validate_all(self) -> None:
-        """Validates each catalog, collection contained within this catalog.
+    def validate_all(self, max_items: int | None = None, recursive: bool = True) -> int:
+        """Validates each catalog, collection, item contained within this catalog.
 
         Walks through the children and items of the catalog and validates each
         stac object.
 
+        Args:
+            max_items : The maximum number of STAC items to validate. Default
+                is None which means, validate them all.
+            recursive : Whether to validate catalog, collections, and items contained
+                within child objects.
+
+        Returns:
+            int : Number of STAC items validated.
+
         Raises:
             STACValidationError: Raises this error on any item that is invalid.
                 Will raise on the first invalid stac object encountered.
         """
+        n = 0
         self.validate()
         for child in self.get_children():
-            child.validate_all()
+            if recursive:
+                inner_max_items = None if max_items is None else max_items - n
+                n += child.validate_all(max_items=inner_max_items, recursive=True)
+            else:
+                child.validate()
         for item in self.get_items():
+            if max_items is not None and n >= max_items:
+                break
             item.validate()
+            n += 1
+        return n
 
-    def _object_links(self) -> List[Union[str, pystac.RelType]]:
+    def _object_links(self) -> list[str | pystac.RelType]:
         return [
             pystac.RelType.CHILD,
             pystac.RelType.ITEM,
@@ -950,7 +1066,7 @@ class Catalog(STACObject):
 
     def map_items(
         self,
-        item_mapper: Callable[[Item], Union[Item, List[Item]]],
+        item_mapper: Callable[[Item], Item | list[Item]],
     ) -> Catalog:
         """Creates a copy of a catalog, with each item passed through the
         item_mapper function.
@@ -971,7 +1087,7 @@ class Catalog(STACObject):
             for child in catalog.get_children():
                 process_catalog(child)
 
-            item_links: List[Link] = []
+            item_links: list[Link] = []
             for item_link in catalog.get_item_links():
                 item_link.resolve_stac_object(root=self.get_root())
                 mapped = item_mapper(cast(pystac.Item, item_link.target))
@@ -995,7 +1111,7 @@ class Catalog(STACObject):
         self,
         asset_mapper: Callable[
             [str, Asset],
-            Union[Asset, Tuple[str, Asset], Dict[str, Asset]],
+            Asset | tuple[str, Asset] | dict[str, Asset],
         ],
     ) -> Catalog:
         """Creates a copy of a catalog, with each Asset for each Item passed
@@ -1013,8 +1129,8 @@ class Catalog(STACObject):
         """
 
         def apply_asset_mapper(
-            tup: Tuple[str, Asset]
-        ) -> List[Tuple[str, pystac.Asset]]:
+            tup: tuple[str, Asset]
+        ) -> list[tuple[str, pystac.Asset]]:
             k, v = tup
             result = asset_mapper(k, v)
             if result is None:
@@ -1050,22 +1166,22 @@ class Catalog(STACObject):
         """
         s = "{}* {}".format(" " * _indent, self)
         if include_hrefs:
-            s += " {}".format(self.get_self_href())
+            s += f" {self.get_self_href()}"
         print(s)
         for child in self.get_children():
             child.describe(include_hrefs=include_hrefs, _indent=_indent + 4)
         for item in self.get_items():
             s = "{}* {}".format(" " * (_indent + 2), item)
             if include_hrefs:
-                s += " {}".format(item.get_self_href())
+                s += f" {item.get_self_href()}"
             print(s)
 
     @classmethod
     def from_dict(
-        cls: Type[C],
-        d: Dict[str, Any],
-        href: Optional[str] = None,
-        root: Optional["Catalog"] = None,
+        cls: type[C],
+        d: dict[str, Any],
+        href: str | None = None,
+        root: Catalog | None = None,
         migrate: bool = False,
         preserve_dict: bool = True,
     ) -> C:
@@ -1074,7 +1190,7 @@ class Catalog(STACObject):
             d = migrate_to_latest(d, info)
 
         if not cls.matches_object_type(d):
-            raise STACTypeError(f"{d} does not represent a {cls.__name__} instance")
+            raise STACTypeError(d, cls)
 
         catalog_type = CatalogType.determine_type(d)
 
@@ -1113,24 +1229,32 @@ class Catalog(STACObject):
         return cat
 
     def full_copy(
-        self, root: Optional["Catalog"] = None, parent: Optional["Catalog"] = None
+        self, root: Catalog | None = None, parent: Catalog | None = None
     ) -> Catalog:
         return cast(Catalog, super().full_copy(root, parent))
 
     @classmethod
-    def from_file(
-        cls: Type[C], href: str, stac_io: Optional[pystac.StacIO] = None
-    ) -> C:
+    def from_file(cls: type[C], href: HREF, stac_io: pystac.StacIO | None = None) -> C:
         if stac_io is None:
             stac_io = pystac.StacIO.default()
 
         result = super().from_file(href, stac_io)
-        if not isinstance(result, Catalog):
-            raise pystac.STACTypeError(f"{result} is not a {Catalog}.")
         result._stac_io = stac_io
 
         return result
 
     @classmethod
-    def matches_object_type(cls, d: Dict[str, Any]) -> bool:
+    def matches_object_type(cls, d: dict[str, Any]) -> bool:
         return identify_stac_object_type(d) == STACObjectType.CATALOG
+
+    @property
+    def ext(self) -> CatalogExt:
+        """Accessor for extension classes on this catalog
+
+        Example::
+
+            print(collection.ext.version)
+        """
+        from pystac.extensions.ext import CatalogExt
+
+        return CatalogExt(stac_object=self)
