@@ -1,17 +1,13 @@
 from __future__ import annotations
 
 import warnings
+from collections.abc import Iterable
 from copy import deepcopy
 from datetime import datetime
 from typing import (
     TYPE_CHECKING,
     Any,
-    Dict,
-    Iterable,
-    List,
     Optional,
-    Tuple,
-    Type,
     TypeVar,
     Union,
     cast,
@@ -20,8 +16,8 @@ from typing import (
 from dateutil import tz
 
 import pystac
-from pystac import CatalogType, STACError, STACObjectType
-from pystac.asset import Asset
+from pystac import CatalogType, STACObjectType
+from pystac.asset import Asset, Assets
 from pystac.catalog import Catalog
 from pystac.errors import DeprecatedWarning, ExtensionNotImplemented, STACTypeError
 from pystac.layout import HrefLayoutStrategy
@@ -35,20 +31,19 @@ from pystac.serialization import (
 from pystac.summaries import Summaries
 from pystac.utils import (
     datetime_to_str,
-    is_absolute_href,
-    make_absolute_href,
-    make_relative_href,
     str_to_datetime,
 )
 
 if TYPE_CHECKING:
+    from pystac.extensions.ext import CollectionExt
     from pystac.item import Item
 
 C = TypeVar("C", bound="Collection")
 
-TemporalIntervals = Union[List[List[datetime]], List[List[Optional[datetime]]]]
+Bboxes = list[list[Union[float, int]]]
+TemporalIntervals = Union[list[list[datetime]], list[list[Optional[datetime]]]]
 TemporalIntervalsLike = Union[
-    TemporalIntervals, List[datetime], List[Optional[datetime]]
+    TemporalIntervals, list[datetime], list[Optional[datetime]]
 ]
 
 
@@ -65,31 +60,34 @@ class SpatialExtent:
             Spatial Extent object.
     """
 
-    bboxes: List[List[float]]
+    bboxes: Bboxes
     """A list of bboxes that represent the spatial
     extent of the collection. Each bbox can be 2D or 3D. The length of the bbox
     array must be 2*n where n is the number of dimensions. For example, a
     2D Collection with only one bbox would be [[xmin, ymin, xmax, ymax]]"""
 
-    extra_fields: Dict[str, Any]
+    extra_fields: dict[str, Any]
     """Dictionary containing additional top-level fields defined on the Spatial
     Extent object."""
 
     def __init__(
         self,
-        bboxes: Union[List[List[float]], List[float]],
-        extra_fields: Optional[Dict[str, Any]] = None,
+        bboxes: Bboxes | list[float | int],
+        extra_fields: dict[str, Any] | None = None,
     ) -> None:
+        if not isinstance(bboxes, list):
+            raise TypeError("bboxes must be a list")
+
         # A common mistake is to pass in a single bbox instead of a list of bboxes.
         # Account for this by transforming the input in that case.
-        if isinstance(bboxes, list) and isinstance(bboxes[0], float):
-            self.bboxes: List[List[float]] = [cast(List[float], bboxes)]
+        if isinstance(bboxes[0], (float, int)):
+            self.bboxes = [cast(list[Union[float, int]], bboxes)]
         else:
-            self.bboxes = cast(List[List[float]], bboxes)
+            self.bboxes = cast(Bboxes, bboxes)
 
         self.extra_fields = extra_fields or {}
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         """Returns this spatial extent as a dictionary.
 
         Returns:
@@ -110,7 +108,7 @@ class SpatialExtent:
         )
 
     @staticmethod
-    def from_dict(d: Dict[str, Any]) -> SpatialExtent:
+    def from_dict(d: dict[str, Any]) -> SpatialExtent:
         """Constructs a SpatialExtent from a dict.
 
         Returns:
@@ -122,7 +120,7 @@ class SpatialExtent:
 
     @staticmethod
     def from_coordinates(
-        coordinates: List[Any], extra_fields: Optional[Dict[str, Any]] = None
+        coordinates: list[Any], extra_fields: dict[str, Any] | None = None
     ) -> SpatialExtent:
         """Constructs a SpatialExtent from a set of coordinates.
 
@@ -140,12 +138,12 @@ class SpatialExtent:
         """
 
         def process_coords(
-            coord_lists: List[Any],
-            xmin: Optional[float] = None,
-            ymin: Optional[float] = None,
-            xmax: Optional[float] = None,
-            ymax: Optional[float] = None,
-        ) -> Tuple[Optional[float], Optional[float], Optional[float], Optional[float]]:
+            coord_lists: list[Any],
+            xmin: float | None = None,
+            ymin: float | None = None,
+            xmax: float | None = None,
+            ymax: float | None = None,
+        ) -> tuple[float | None, float | None, float | None, float | None]:
             for coord in coord_lists:
                 if isinstance(coord[0], list):
                     xmin, ymin, xmax, ymax = process_coords(
@@ -196,32 +194,34 @@ class TemporalExtent:
     represented by either the start (the first element of the interval) or the
     end (the second element of the interval) being None."""
 
-    extra_fields: Dict[str, Any]
+    extra_fields: dict[str, Any]
     """Dictionary containing additional top-level fields defined on the Temporal
     Extent object."""
 
     def __init__(
         self,
-        intervals: TemporalIntervals,
-        extra_fields: Optional[Dict[str, Any]] = None,
+        intervals: TemporalIntervals | list[datetime | None],
+        extra_fields: dict[str, Any] | None = None,
     ):
+        if not isinstance(intervals, list):
+            raise TypeError("intervals must be a list")
         # A common mistake is to pass in a single interval instead of a
         # list of intervals. Account for this by transforming the input
         # in that case.
-        if isinstance(intervals, list) and isinstance(intervals[0], datetime):
-            self.intervals = intervals
+        if isinstance(intervals[0], datetime) or intervals[0] is None:
+            self.intervals = [cast(list[Optional[datetime]], intervals)]
         else:
-            self.intervals = intervals
+            self.intervals = cast(TemporalIntervals, intervals)
 
         self.extra_fields = extra_fields or {}
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         """Returns this temporal extent as a dictionary.
 
         Returns:
             dict: A serialization of the TemporalExtent.
         """
-        encoded_intervals: List[List[Optional[str]]] = []
+        encoded_intervals: list[list[str | None]] = []
         for i in self.intervals:
             start = None
             end = None
@@ -249,14 +249,28 @@ class TemporalExtent:
         )
 
     @staticmethod
-    def from_dict(d: Dict[str, Any]) -> TemporalExtent:
+    def from_dict(d: dict[str, Any]) -> TemporalExtent:
         """Constructs an TemporalExtent from a dict.
 
         Returns:
             TemporalExtent: The TemporalExtent deserialized from the JSON dict.
         """
-        parsed_intervals: List[List[Optional[datetime]]] = []
+        parsed_intervals: list[list[datetime | None]] = []
         for i in d["interval"]:
+            if isinstance(i, str):
+                # d["interval"] is a list of strings, so we correct the list and
+                # try again
+                # https://github.com/stac-utils/pystac/issues/1221
+                warnings.warn(
+                    "A collection's temporal extent should be a list of lists, but "
+                    "is instead a "
+                    "list of strings. pystac is fixing this issue and continuing "
+                    "deserialization, but note that the source "
+                    "collection is invalid STAC.",
+                    UserWarning,
+                )
+                d["interval"] = [d["interval"]]
+                return TemporalExtent.from_dict(d)
             start = None
             end = None
 
@@ -300,7 +314,7 @@ class Extent:
     temporal: TemporalExtent
     """Potential temporal extent covered by the collection."""
 
-    extra_fields: Dict[str, Any]
+    extra_fields: dict[str, Any]
     """Dictionary containing additional top-level fields defined on the Extent
     object."""
 
@@ -308,13 +322,13 @@ class Extent:
         self,
         spatial: SpatialExtent,
         temporal: TemporalExtent,
-        extra_fields: Optional[Dict[str, Any]] = None,
+        extra_fields: dict[str, Any] | None = None,
     ):
         self.spatial = spatial
         self.temporal = temporal
         self.extra_fields = extra_fields or {}
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         """Returns this extent as a dictionary.
 
         Returns:
@@ -342,7 +356,7 @@ class Extent:
         )
 
     @staticmethod
-    def from_dict(d: Dict[str, Any]) -> Extent:
+    def from_dict(d: dict[str, Any]) -> Extent:
         """Constructs an Extent from a dict.
 
         Returns:
@@ -358,7 +372,7 @@ class Extent:
 
     @staticmethod
     def from_items(
-        items: Iterable[Item], extra_fields: Optional[Dict[str, Any]] = None
+        items: Iterable[Item], extra_fields: dict[str, Any] | None = None
     ) -> Extent:
         """Create an Extent based on the datetimes and bboxes of a list of items.
 
@@ -371,15 +385,15 @@ class Extent:
             Extent: An Extent that spatially and temporally covers all of the
             given items.
         """
-        bounds_values: List[List[float]] = [
+        bounds_values: list[list[float]] = [
             [float("inf")],
             [float("inf")],
             [float("-inf")],
             [float("-inf")],
         ]
-        datetimes: List[datetime] = []
-        starts: List[datetime] = []
-        ends: List[datetime] = []
+        datetimes: list[datetime] = []
+        starts: list[datetime] = []
+        ends: list[datetime] = []
 
         for item in items:
             if item.bbox is not None:
@@ -426,7 +440,7 @@ class Extent:
         return Extent(spatial=spatial, temporal=temporal, extra_fields=extra_fields)
 
 
-class Collection(Catalog):
+class Collection(Catalog, Assets):
     """A Collection extends the Catalog spec with additional metadata that helps
     enable discovery.
 
@@ -461,9 +475,6 @@ class Collection(Catalog):
             :attr:`~pystac.Asset.owner` attribute set to the created Collection.
     """
 
-    assets: Dict[str, Asset]
-    """Map of Assets"""
-
     description: str
     """Detailed multi-line description to fully explain the collection."""
 
@@ -474,27 +485,27 @@ class Collection(Catalog):
     id: str
     """Identifier for the collection."""
 
-    stac_extensions: List[str]
+    stac_extensions: list[str]
     """List of extensions the Collection implements."""
 
-    title: Optional[str]
+    title: str | None
     """Optional short descriptive one-line title for the collection."""
 
-    keywords: Optional[List[str]]
+    keywords: list[str] | None
     """Optional list of keywords describing the collection."""
 
-    providers: Optional[List[Provider]]
+    providers: list[Provider] | None
     """Optional list of providers of this Collection."""
 
     summaries: Summaries
     """A map of property summaries, either a set of values or statistics such as a
     range."""
 
-    links: List[Link]
+    links: list[Link]
     """A list of :class:`~pystac.Link` objects representing all links associated with
     this Collection."""
 
-    extra_fields: Dict[str, Any]
+    extra_fields: dict[str, Any]
     """Extra fields that are part of the top-level JSON properties of the Collection."""
 
     STAC_OBJECT_TYPE = STACObjectType.COLLECTION
@@ -508,16 +519,16 @@ class Collection(Catalog):
         id: str,
         description: str,
         extent: Extent,
-        title: Optional[str] = None,
-        stac_extensions: Optional[List[str]] = None,
-        href: Optional[str] = None,
-        extra_fields: Optional[Dict[str, Any]] = None,
-        catalog_type: Optional[CatalogType] = None,
+        title: str | None = None,
+        stac_extensions: list[str] | None = None,
+        href: str | None = None,
+        extra_fields: dict[str, Any] | None = None,
+        catalog_type: CatalogType | None = None,
         license: str = "proprietary",
-        keywords: Optional[List[str]] = None,
-        providers: Optional[List[Provider]] = None,
-        summaries: Optional[Summaries] = None,
-        assets: Optional[Dict[str, Asset]] = None,
+        keywords: list[str] | None = None,
+        providers: list[Provider] | None = None,
+        summaries: Summaries | None = None,
+        assets: dict[str, Asset] | None = None,
     ):
         super().__init__(
             id,
@@ -531,7 +542,7 @@ class Collection(Catalog):
         self.extent = extent
         self.license = license
 
-        self.stac_extensions: List[str] = stac_extensions or []
+        self.stac_extensions: list[str] = stac_extensions or []
         self.keywords = keywords
         self.providers = providers
         self.summaries = summaries or Summaries.empty()
@@ -542,13 +553,13 @@ class Collection(Catalog):
                 self.add_asset(k, asset)
 
     def __repr__(self) -> str:
-        return "<Collection id={}>".format(self.id)
+        return f"<Collection id={self.id}>"
 
     def add_item(
         self,
         item: Item,
-        title: Optional[str] = None,
-        strategy: Optional[HrefLayoutStrategy] = None,
+        title: str | None = None,
+        strategy: HrefLayoutStrategy | None = None,
         set_parent: bool = True,
     ) -> Link:
         link = super().add_item(item, title, strategy, set_parent)
@@ -557,7 +568,7 @@ class Collection(Catalog):
 
     def to_dict(
         self, include_self_link: bool = True, transform_hrefs: bool = True
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         d = super().to_dict(
             include_self_link=include_self_link, transform_hrefs=transform_hrefs
         )
@@ -610,10 +621,10 @@ class Collection(Catalog):
 
     @classmethod
     def from_dict(
-        cls: Type[C],
-        d: Dict[str, Any],
-        href: Optional[str] = None,
-        root: Optional[Catalog] = None,
+        cls: type[C],
+        d: dict[str, Any],
+        href: str | None = None,
+        root: Catalog | None = None,
         migrate: bool = False,
         preserve_dict: bool = True,
     ) -> C:
@@ -692,7 +703,7 @@ class Collection(Catalog):
 
         return collection
 
-    def get_item(self, id: str, recursive: bool = False) -> Optional[Item]:
+    def get_item(self, id: str, recursive: bool = False) -> Item | None:
         """Returns an item with a given ID.
 
         Args:
@@ -713,95 +724,6 @@ class Collection(Catalog):
                 return super().get_item(id, recursive=recursive)
             raise e
 
-    def get_assets(
-        self,
-        media_type: Optional[Union[str, pystac.MediaType]] = None,
-        role: Optional[str] = None,
-    ) -> Dict[str, Asset]:
-        """Get this collection's assets.
-
-        Args:
-            media_type: If set, filter the assets such that only those with a
-                matching ``media_type`` are returned.
-            role: If set, filter the assets such that only those with a matching
-                ``role`` are returned.
-
-        Returns:
-            Dict[str, Asset]: A dictionary of assets that match ``media_type``
-            and/or ``role`` if set or else all of this collection's assets.
-        """
-        return {
-            k: deepcopy(v)
-            for k, v in self.assets.items()
-            if (media_type is None or v.media_type == media_type)
-            and (role is None or v.has_role(role))
-        }
-
-    def add_asset(self, key: str, asset: Asset) -> None:
-        """Adds an Asset to this collection.
-
-        Args:
-            key : The unique key of this asset.
-            asset : The Asset to add.
-        """
-        asset.set_owner(self)
-        self.assets[key] = asset
-
-    def delete_asset(self, key: str) -> None:
-        """Deletes the asset at the given key, and removes the asset's data
-        file from the local filesystem.
-
-        It is an error to attempt to delete an asset's file if it is on a
-        remote filesystem.
-
-        To delete the asset without removing the file, use
-        `del collection.assets["key"]`.
-
-        Args:
-            key: The unique key of this asset.
-        """
-        asset = self.assets[key]
-        asset.set_owner(self)
-        asset.delete()
-
-        del self.assets[key]
-
-    def make_asset_hrefs_relative(self) -> Collection:
-        """Modify each asset's HREF to be relative to this collection's self HREF.
-
-        Returns:
-            Collection: self
-        """
-        self_href = self.get_self_href()
-        for asset in self.assets.values():
-            if is_absolute_href(asset.href):
-                if self_href is None:
-                    raise STACError(
-                        "Cannot make asset HREFs relative " "if no self_href is set."
-                    )
-                asset.href = make_relative_href(asset.href, self_href)
-        return self
-
-    def make_asset_hrefs_absolute(self) -> Collection:
-        """Modify each asset's HREF to be absolute.
-
-        Any asset HREFs that are relative will be modified to absolute based on this
-        collection's self HREF.
-
-        Returns:
-            Collection: self
-        """
-        self_href = self.get_self_href()
-        for asset in self.assets.values():
-            if not is_absolute_href(asset.href):
-                if self_href is None:
-                    raise STACError(
-                        "Cannot make relative asset HREFs absolute "
-                        "if no self_href is set."
-                    )
-                asset.href = make_absolute_href(asset.href, self_href)
-        return self
-
     def update_extent_from_items(self) -> None:
         """
         Update datetime and bbox based on all items to a single bbox and time window.
@@ -809,10 +731,22 @@ class Collection(Catalog):
         self.extent = Extent.from_items(self.get_items(recursive=True))
 
     def full_copy(
-        self, root: Optional["Catalog"] = None, parent: Optional["Catalog"] = None
+        self, root: Catalog | None = None, parent: Catalog | None = None
     ) -> Collection:
         return cast(Collection, super().full_copy(root, parent))
 
     @classmethod
-    def matches_object_type(cls, d: Dict[str, Any]) -> bool:
+    def matches_object_type(cls, d: dict[str, Any]) -> bool:
         return identify_stac_object_type(d) == STACObjectType.COLLECTION
+
+    @property
+    def ext(self) -> CollectionExt:
+        """Accessor for extension classes on this collection
+
+        Example::
+
+            print(collection.ext.xarray)
+        """
+        from pystac.extensions.ext import CollectionExt
+
+        return CollectionExt(stac_object=self)
