@@ -2,21 +2,19 @@
 
 from __future__ import annotations
 
+import warnings
+from collections.abc import Iterable
 from typing import (
     Any,
-    Dict,
     Generic,
-    Iterable,
-    List,
-    Optional,
-    Tuple,
+    Literal,
     TypeVar,
     Union,
     cast,
 )
 
 import pystac
-from pystac.extensions import projection, view
+from pystac.extensions import item_assets, projection, view
 from pystac.extensions.base import (
     ExtensionManagementMixin,
     PropertiesExtension,
@@ -27,14 +25,27 @@ from pystac.serialization.identify import STACJSONDescription, STACVersionID
 from pystac.summaries import RangeSummary
 from pystac.utils import get_required, map_opt
 
-T = TypeVar("T", pystac.Item, pystac.Asset)
+T = TypeVar("T", pystac.Item, pystac.Asset, item_assets.AssetDefinition)
 
-SCHEMA_URI: str = "https://stac-extensions.github.io/eo/v1.0.0/schema.json"
+SCHEMA_URI: str = "https://stac-extensions.github.io/eo/v1.1.0/schema.json"
+SCHEMA_URIS: list[str] = [
+    "https://stac-extensions.github.io/eo/v1.0.0/schema.json",
+    SCHEMA_URI,
+]
 PREFIX: str = "eo:"
 
 # Field names
 BANDS_PROP: str = PREFIX + "bands"
 CLOUD_COVER_PROP: str = PREFIX + "cloud_cover"
+SNOW_COVER_PROP: str = PREFIX + "snow_cover"
+
+
+def validated_percentage(v: float | None) -> float | None:
+    if v is not None and not isinstance(v, (float, int)) or isinstance(v, bool):
+        raise ValueError(f"Invalid percentage: {v} must be number")
+    if v is not None and not 0 <= v <= 100:
+        raise ValueError(f"Invalid percentage: {v} must be between 0 and 100")
+    return v
 
 
 class Band:
@@ -43,19 +54,19 @@ class Band:
     Use :meth:`Band.create` to create a new Band.
     """
 
-    properties: Dict[str, Any]
+    properties: dict[str, Any]
 
-    def __init__(self, properties: Dict[str, Any]) -> None:
+    def __init__(self, properties: dict[str, Any]) -> None:
         self.properties = properties
 
     def apply(
         self,
         name: str,
-        common_name: Optional[str] = None,
-        description: Optional[str] = None,
-        center_wavelength: Optional[float] = None,
-        full_width_half_max: Optional[float] = None,
-        solar_illumination: Optional[float] = None,
+        common_name: str | None = None,
+        description: str | None = None,
+        center_wavelength: float | None = None,
+        full_width_half_max: float | None = None,
+        solar_illumination: float | None = None,
     ) -> None:
         """
         Sets the properties for this Band.
@@ -83,11 +94,11 @@ class Band:
     def create(
         cls,
         name: str,
-        common_name: Optional[str] = None,
-        description: Optional[str] = None,
-        center_wavelength: Optional[float] = None,
-        full_width_half_max: Optional[float] = None,
-        solar_illumination: Optional[float] = None,
+        common_name: str | None = None,
+        description: str | None = None,
+        center_wavelength: float | None = None,
+        full_width_half_max: float | None = None,
+        solar_illumination: float | None = None,
     ) -> Band:
         """
         Creates a new band.
@@ -129,7 +140,7 @@ class Band:
         self.properties["name"] = v
 
     @property
-    def common_name(self) -> Optional[str]:
+    def common_name(self) -> str | None:
         """Get or sets the name commonly used to refer to the band to make it easier
             to search for bands across instruments. See the :stac-ext:`list of accepted
             common names <eo#common-band-names>`.
@@ -140,14 +151,14 @@ class Band:
         return self.properties.get("common_name")
 
     @common_name.setter
-    def common_name(self, v: Optional[str]) -> None:
+    def common_name(self, v: str | None) -> None:
         if v is not None:
             self.properties["common_name"] = v
         else:
             self.properties.pop("common_name", None)
 
     @property
-    def description(self) -> Optional[str]:
+    def description(self) -> str | None:
         """Get or sets the description to fully explain the band. CommonMark 0.29
         syntax MAY be used for rich text representation.
 
@@ -157,14 +168,14 @@ class Band:
         return self.properties.get("description")
 
     @description.setter
-    def description(self, v: Optional[str]) -> None:
+    def description(self, v: str | None) -> None:
         if v is not None:
             self.properties["description"] = v
         else:
             self.properties.pop("description", None)
 
     @property
-    def center_wavelength(self) -> Optional[float]:
+    def center_wavelength(self) -> float | None:
         """Get or sets the center wavelength of the band, in micrometers (μm).
 
         Returns:
@@ -173,14 +184,14 @@ class Band:
         return self.properties.get("center_wavelength")
 
     @center_wavelength.setter
-    def center_wavelength(self, v: Optional[float]) -> None:
+    def center_wavelength(self, v: float | None) -> None:
         if v is not None:
             self.properties["center_wavelength"] = v
         else:
             self.properties.pop("center_wavelength", None)
 
     @property
-    def full_width_half_max(self) -> Optional[float]:
+    def full_width_half_max(self) -> float | None:
         """Get or sets the full width at half maximum (FWHM). The width of the band,
             as measured at half the maximum transmission, in micrometers (μm).
 
@@ -190,14 +201,14 @@ class Band:
         return self.properties.get("full_width_half_max")
 
     @full_width_half_max.setter
-    def full_width_half_max(self, v: Optional[float]) -> None:
+    def full_width_half_max(self, v: float | None) -> None:
         if v is not None:
             self.properties["full_width_half_max"] = v
         else:
             self.properties.pop("full_width_half_max", None)
 
     @property
-    def solar_illumination(self) -> Optional[float]:
+    def solar_illumination(self) -> float | None:
         """Get or sets the solar illumination of the band,
             as measured at half the maximum transmission, in W/m2/micrometers.
 
@@ -207,25 +218,25 @@ class Band:
         return self.properties.get("solar_illumination")
 
     @solar_illumination.setter
-    def solar_illumination(self, v: Optional[float]) -> None:
+    def solar_illumination(self, v: float | None) -> None:
         if v is not None:
             self.properties["solar_illumination"] = v
         else:
             self.properties.pop("solar_illumination", None)
 
     def __repr__(self) -> str:
-        return "<Band name={}>".format(self.name)
+        return f"<Band name={self.name}>"
 
-    def to_dict(self) -> Dict[str, Any]:
-        """Returns the dictionary representing the JSON of this Band.
+    def to_dict(self) -> dict[str, Any]:
+        """Returns this band as a dictionary.
 
         Returns:
-            dict: The wrapped dict of the Band that can be written out as JSON.
+            dict: The serialization of this Band.
         """
         return self.properties
 
     @staticmethod
-    def band_range(common_name: str) -> Optional[Tuple[float, float]]:
+    def band_range(common_name: str) -> tuple[float, float] | None:
         """Gets the band range for a common band name.
 
         Args:
@@ -258,7 +269,7 @@ class Band:
         return name_to_range.get(common_name)
 
     @staticmethod
-    def band_description(common_name: str) -> Optional[str]:
+    def band_description(common_name: str) -> str | None:
         """Returns a description of the band for one with a common name.
 
         Args:
@@ -271,7 +282,7 @@ class Band:
         """
         r = Band.band_range(common_name)
         if r is not None:
-            return "Common name: {}, Range: {} to {}".format(common_name, r[0], r[1])
+            return f"Common name: {common_name}, Range: {r[0]} to {r[1]}"
         return None
 
 
@@ -295,8 +306,13 @@ class EOExtension(
        >>> eo_ext = EOExtension.ext(item)
     """
 
+    name: Literal["eo"] = "eo"
+
     def apply(
-        self, bands: Optional[List[Band]] = None, cloud_cover: Optional[float] = None
+        self,
+        bands: list[Band] | None = None,
+        cloud_cover: float | None = None,
+        snow_cover: float | None = None,
     ) -> None:
         """Applies Electro-Optical Extension properties to the extended
         :class:`~pystac.Item` or :class:`~pystac.Asset`.
@@ -307,12 +323,16 @@ class EOExtension(
             cloud_cover : The estimate of cloud cover as a percentage
                 (0-100) of the entire scene. If not available the field should not
                 be provided.
+            snow_cover : The estimate of snow cover as a percentage
+                (0-100) of the entire scene. If not available the field should not
+                be provided.
         """
         self.bands = bands
-        self.cloud_cover = cloud_cover
+        self.cloud_cover = validated_percentage(cloud_cover)
+        self.snow_cover = validated_percentage(snow_cover)
 
     @property
-    def bands(self) -> Optional[List[Band]]:
+    def bands(self) -> list[Band] | None:
         """Gets or sets a list of available bands where each item is a :class:`~Band`
         object (or ``None`` if no bands have been set). If not available the field
         should not be provided.
@@ -320,19 +340,19 @@ class EOExtension(
         return self._get_bands()
 
     @bands.setter
-    def bands(self, v: Optional[List[Band]]) -> None:
+    def bands(self, v: list[Band] | None) -> None:
         self._set_property(
             BANDS_PROP, map_opt(lambda bands: [b.to_dict() for b in bands], v)
         )
 
-    def _get_bands(self) -> Optional[List[Band]]:
+    def _get_bands(self) -> list[Band] | None:
         return map_opt(
             lambda bands: [Band(b) for b in bands],
-            self._get_property(BANDS_PROP, List[Dict[str, Any]]),
+            self._get_property(BANDS_PROP, list[dict[str, Any]]),
         )
 
     @property
-    def cloud_cover(self) -> Optional[float]:
+    def cloud_cover(self) -> float | None:
         """Get or sets the estimate of cloud cover as a percentage
         (0-100) of the entire scene. If not available the field should not be provided.
 
@@ -342,13 +362,35 @@ class EOExtension(
         return self._get_property(CLOUD_COVER_PROP, float)
 
     @cloud_cover.setter
-    def cloud_cover(self, v: Optional[float]) -> None:
-        self._set_property(CLOUD_COVER_PROP, v)
+    def cloud_cover(self, v: float | None) -> None:
+        self._set_property(CLOUD_COVER_PROP, validated_percentage(v), pop_if_none=True)
+
+    @property
+    def snow_cover(self) -> float | None:
+        """Get or sets the estimate of snow cover as a percentage
+        (0-100) of the entire scene. If not available the field should not be provided.
+
+        Returns:
+            float or None
+        """
+        return self._get_property(SNOW_COVER_PROP, float)
+
+    @snow_cover.setter
+    def snow_cover(self, v: float | None) -> None:
+        self._set_property(SNOW_COVER_PROP, validated_percentage(v), pop_if_none=True)
 
     @classmethod
     def get_schema_uri(cls) -> str:
         return SCHEMA_URI
 
+    @classmethod
+    def get_schema_uris(cls) -> list[str]:
+        warnings.warn(
+            "get_schema_uris is deprecated and will be removed in v2",
+            DeprecationWarning,
+        )
+        return SCHEMA_URIS
+
     @classmethod
     def ext(cls, obj: T, add_if_missing: bool = False) -> EOExtension[T]:
         """Extends the given STAC Object with properties from the
@@ -362,22 +404,23 @@ class EOExtension(
             pystac.ExtensionTypeError : If an invalid object type is passed.
         """
         if isinstance(obj, pystac.Item):
-            cls.validate_has_extension(obj, add_if_missing)
+            cls.ensure_has_extension(obj, add_if_missing)
             return cast(EOExtension[T], ItemEOExtension(obj))
         elif isinstance(obj, pystac.Asset):
-            cls.validate_owner_has_extension(obj, add_if_missing)
+            cls.ensure_owner_has_extension(obj, add_if_missing)
             return cast(EOExtension[T], AssetEOExtension(obj))
+        elif isinstance(obj, item_assets.AssetDefinition):
+            cls.ensure_owner_has_extension(obj, add_if_missing)
+            return cast(EOExtension[T], ItemAssetsEOExtension(obj))
         else:
-            raise pystac.ExtensionTypeError(
-                f"EO extension does not apply to type '{type(obj).__name__}'"
-            )
+            raise pystac.ExtensionTypeError(cls._ext_error_message(obj))
 
     @classmethod
     def summaries(
         cls, obj: pystac.Collection, add_if_missing: bool = False
     ) -> SummariesEOExtension:
         """Returns the extended summaries object for the given collection."""
-        cls.validate_has_extension(obj, add_if_missing)
+        cls.ensure_has_extension(obj, add_if_missing)
         return SummariesEOExtension(obj)
 
 
@@ -393,26 +436,26 @@ class ItemEOExtension(EOExtension[pystac.Item]):
     item: pystac.Item
     """The :class:`~pystac.Item` being extended."""
 
-    properties: Dict[str, Any]
+    properties: dict[str, Any]
     """The :class:`~pystac.Item` properties, including extension properties."""
 
     def __init__(self, item: pystac.Item):
         self.item = item
         self.properties = item.properties
 
-    def _get_bands(self) -> Optional[List[Band]]:
+    def _get_bands(self) -> list[Band] | None:
         """Get or sets a list of :class:`~pystac.Band` objects that represent
         the available bands.
         """
-        bands = self._get_property(BANDS_PROP, List[Dict[str, Any]])
+        bands = self._get_property(BANDS_PROP, list[dict[str, Any]])
 
         # get assets with eo:bands even if not in item
         if bands is None:
-            asset_bands: List[Dict[str, Any]] = []
+            asset_bands: list[dict[str, Any]] = []
             for _, value in self.item.get_assets().items():
                 if BANDS_PROP in value.extra_fields:
                     asset_bands.extend(
-                        cast(List[Dict[str, Any]], value.extra_fields.get(BANDS_PROP))
+                        cast(list[dict[str, Any]], value.extra_fields.get(BANDS_PROP))
                     )
             if any(asset_bands):
                 bands = asset_bands
@@ -421,8 +464,37 @@ class ItemEOExtension(EOExtension[pystac.Item]):
             return [Band(b) for b in bands]
         return None
 
+    def get_assets(
+        self,
+        name: str | None = None,
+        common_name: str | None = None,
+    ) -> dict[str, pystac.Asset]:
+        """Get the item's assets where eo:bands are defined.
+
+        Args:
+            name: If set, filter the assets such that only those with a
+                matching ``eo:band.name`` are returned.
+            common_name: If set, filter the assets such that only those with a matching
+                ``eo:band.common_name`` are returned.
+
+        Returns:
+            Dict[str, Asset]: A dictionary of assets that match ``name``
+                and/or ``common_name`` if set or else all of this item's assets were
+                eo:bands are defined.
+        """
+        kwargs = {"name": name, "common_name": common_name}
+        return {
+            key: asset
+            for key, asset in self.item.get_assets().items()
+            if BANDS_PROP in asset.extra_fields
+            and all(
+                v is None or any(v == b.get(k) for b in asset.extra_fields[BANDS_PROP])
+                for k, v in kwargs.items()
+            )
+        }
+
     def __repr__(self) -> str:
-        return "<ItemEOExtension Item id={}>".format(self.item.id)
+        return f"<ItemEOExtension Item id={self.item.id}>"
 
 
 class AssetEOExtension(EOExtension[pystac.Asset]):
@@ -437,20 +509,20 @@ class AssetEOExtension(EOExtension[pystac.Asset]):
     asset_href: str
     """The ``href`` value of the :class:`~pystac.Asset` being extended."""
 
-    properties: Dict[str, Any]
+    properties: dict[str, Any]
     """The :class:`~pystac.Asset` fields, including extension properties."""
 
-    additional_read_properties: Optional[Iterable[Dict[str, Any]]] = None
+    additional_read_properties: Iterable[dict[str, Any]] | None = None
     """If present, this will be a list containing 1 dictionary representing the
     properties of the owning :class:`~pystac.Item`."""
 
-    def _get_bands(self) -> Optional[List[Band]]:
+    def _get_bands(self) -> list[Band] | None:
         if BANDS_PROP not in self.properties:
             return None
         return list(
             map(
                 lambda band: Band(band),
-                cast(List[Dict[str, Any]], self.properties.get(BANDS_PROP)),
+                cast(list[dict[str, Any]], self.properties.get(BANDS_PROP)),
             )
         )
 
@@ -461,7 +533,26 @@ class AssetEOExtension(EOExtension[pystac.Asset]):
             self.additional_read_properties = [asset.owner.properties]
 
     def __repr__(self) -> str:
-        return "<AssetEOExtension Asset href={}>".format(self.asset_href)
+        return f"<AssetEOExtension Asset href={self.asset_href}>"
+
+
+class ItemAssetsEOExtension(EOExtension[item_assets.AssetDefinition]):
+    properties: dict[str, Any]
+    asset_defn: item_assets.AssetDefinition
+
+    def _get_bands(self) -> list[Band] | None:
+        if BANDS_PROP not in self.properties:
+            return None
+        return list(
+            map(
+                lambda band: Band(band),
+                cast(list[dict[str, Any]], self.properties.get(BANDS_PROP)),
+            )
+        )
+
+    def __init__(self, item_asset: item_assets.AssetDefinition):
+        self.asset_defn = item_asset
+        self.properties = item_asset.properties
 
 
 class SummariesEOExtension(SummariesExtension):
@@ -471,7 +562,7 @@ class SummariesEOExtension(SummariesExtension):
     """
 
     @property
-    def bands(self) -> Optional[List[Band]]:
+    def bands(self) -> list[Band] | None:
         """Get or sets the summary of :attr:`EOExtension.bands` values
         for this Collection.
         """
@@ -482,28 +573,42 @@ class SummariesEOExtension(SummariesExtension):
         )
 
     @bands.setter
-    def bands(self, v: Optional[List[Band]]) -> None:
+    def bands(self, v: list[Band] | None) -> None:
         self._set_summary(BANDS_PROP, map_opt(lambda x: [b.to_dict() for b in x], v))
 
     @property
-    def cloud_cover(self) -> Optional[RangeSummary[float]]:
+    def cloud_cover(self) -> RangeSummary[float] | None:
         """Get or sets the summary of :attr:`EOExtension.cloud_cover` values
         for this Collection.
         """
         return self.summaries.get_range(CLOUD_COVER_PROP)
 
     @cloud_cover.setter
-    def cloud_cover(self, v: Optional[RangeSummary[float]]) -> None:
+    def cloud_cover(self, v: RangeSummary[float] | None) -> None:
         self._set_summary(CLOUD_COVER_PROP, v)
 
+    @property
+    def snow_cover(self) -> RangeSummary[float] | None:
+        """Get or sets the summary of :attr:`EOExtension.snow_cover` values
+        for this Collection.
+        """
+        return self.summaries.get_range(SNOW_COVER_PROP)
+
+    @snow_cover.setter
+    def snow_cover(self, v: RangeSummary[float] | None) -> None:
+        self._set_summary(SNOW_COVER_PROP, v)
+
 
 class EOExtensionHooks(ExtensionHooks):
     schema_uri: str = SCHEMA_URI
-    prev_extension_ids = {"eo"}
+    prev_extension_ids = {
+        "eo",
+        *[uri for uri in SCHEMA_URIS if uri != SCHEMA_URI],
+    }
     stac_object_types = {pystac.STACObjectType.ITEM}
 
     def migrate(
-        self, obj: Dict[str, Any], version: STACVersionID, info: STACJSONDescription
+        self, obj: dict[str, Any], version: STACVersionID, info: STACJSONDescription
     ) -> None:
         if version < "0.9":
             # Some eo fields became common_metadata
@@ -540,16 +645,16 @@ class EOExtensionHooks(ExtensionHooks):
             ]
 
             for field in eo_to_view_fields:
-                if "eo:{}".format(field) in obj["properties"]:
+                if f"eo:{field}" in obj["properties"]:
                     if "stac_extensions" not in obj:
                         obj["stac_extensions"] = []
                     if view.SCHEMA_URI not in obj["stac_extensions"]:
                         obj["stac_extensions"].append(view.SCHEMA_URI)
-                    if "view:{}".format(field) not in obj["properties"]:
-                        obj["properties"]["view:{}".format(field)] = obj["properties"][
-                            "eo:{}".format(field)
+                    if f"view:{field}" not in obj["properties"]:
+                        obj["properties"][f"view:{field}"] = obj["properties"][
+                            f"eo:{field}"
                         ]
-                        del obj["properties"]["eo:{}".format(field)]
+                        del obj["properties"][f"eo:{field}"]
 
             # eo:epsg became proj:epsg
             eo_epsg = PREFIX + "epsg"
@@ -580,7 +685,7 @@ class EOExtensionHooks(ExtensionHooks):
                 bands = obj["properties"]["eo:bands"]
                 for asset in obj["assets"].values():
                     if "eo:bands" in asset:
-                        new_bands: List[Dict[str, Any]] = []
+                        new_bands: list[dict[str, Any]] = []
                         for band_index in asset["eo:bands"]:
                             new_bands.append(bands[band_index])
                         asset["eo:bands"] = new_bands
