@@ -3,13 +3,19 @@
 from __future__ import annotations
 
 import re
-from typing import Any, Dict, Optional, Pattern, Set, Union
+import warnings
+from re import Pattern
+from typing import Any, Literal, Union
 
 import pystac
 from pystac.extensions.base import ExtensionManagementMixin, PropertiesExtension
 from pystac.extensions.hooks import ExtensionHooks
 
 SCHEMA_URI: str = "https://stac-extensions.github.io/grid/v1.1.0/schema.json"
+SCHEMA_URIS: list[str] = [
+    "https://stac-extensions.github.io/grid/v1.0.0/schema.json",
+    SCHEMA_URI,
+]
 PREFIX: str = "grid:"
 
 # Field names
@@ -46,10 +52,12 @@ class GridExtension(
        >>> proj_ext = GridExtension.ext(item)
     """
 
+    name: Literal["grid"] = "grid"
+
     item: pystac.Item
     """The :class:`~pystac.Item` being extended."""
 
-    properties: Dict[str, Any]
+    properties: dict[str, Any]
     """The :class:`~pystac.Item` properties, including extension properties."""
 
     def __init__(self, item: pystac.Item):
@@ -57,7 +65,7 @@ class GridExtension(
         self.properties = item.properties
 
     def __repr__(self) -> str:
-        return "<ItemGridExtension Item id={}>".format(self.item.id)
+        return f"<ItemGridExtension Item id={self.item.id}>"
 
     def apply(self, code: str) -> None:
         """Applies Grid extension properties to the extended Item.
@@ -68,7 +76,7 @@ class GridExtension(
         self.code = validated_code(code)
 
     @property
-    def code(self) -> Optional[str]:
+    def code(self) -> str | None:
         """Get or sets the latitude band of the datasource."""
         return self._get_property(CODE_PROP, str)
 
@@ -80,6 +88,14 @@ class GridExtension(
     def get_schema_uri(cls) -> str:
         return SCHEMA_URI
 
+    @classmethod
+    def get_schema_uris(cls) -> list[str]:
+        warnings.warn(
+            "get_schema_uris is deprecated and will be removed in v2",
+            DeprecationWarning,
+        )
+        return SCHEMA_URIS
+
     @classmethod
     def ext(cls, obj: pystac.Item, add_if_missing: bool = False) -> GridExtension:
         """Extends the given STAC Object with properties from the :stac-ext:`Grid
@@ -92,18 +108,16 @@ class GridExtension(
             pystac.ExtensionTypeError : If an invalid object type is passed.
         """
         if isinstance(obj, pystac.Item):
-            cls.validate_has_extension(obj, add_if_missing)
+            cls.ensure_has_extension(obj, add_if_missing)
             return GridExtension(obj)
         else:
-            raise pystac.ExtensionTypeError(
-                f"Grid Extension does not apply to type '{type(obj).__name__}'"
-            )
+            raise pystac.ExtensionTypeError(cls._ext_error_message(obj))
 
 
 class GridExtensionHooks(ExtensionHooks):
     schema_uri: str = SCHEMA_URI
-    prev_extension_ids: Set[str] = set()
+    prev_extension_ids: set[str] = {*[uri for uri in SCHEMA_URIS if uri != SCHEMA_URI]}
     stac_object_types = {pystac.STACObjectType.ITEM}
 
 
-Grid_EXTENSION_HOOKS: ExtensionHooks = GridExtensionHooks()
+GRID_EXTENSION_HOOKS: ExtensionHooks = GridExtensionHooks()
