@@ -3,9 +3,19 @@
 from __future__ import annotations
 
 import json
-from typing import Any, Dict, Generic, Iterable, List, Optional, TypeVar, Union, cast
+import warnings
+from collections.abc import Iterable
+from typing import (
+    Any,
+    Generic,
+    Literal,
+    TypeVar,
+    Union,
+    cast,
+)
 
 import pystac
+from pystac.extensions import item_assets
 from pystac.extensions.base import (
     ExtensionManagementMixin,
     PropertiesExtension,
@@ -13,10 +23,10 @@ from pystac.extensions.base import (
 )
 from pystac.extensions.hooks import ExtensionHooks
 
-T = TypeVar("T", pystac.Item, pystac.Asset)
+T = TypeVar("T", pystac.Item, pystac.Asset, item_assets.AssetDefinition)
 
 SCHEMA_URI: str = "https://stac-extensions.github.io/projection/v1.1.0/schema.json"
-SCHEMA_URIS: List[str] = [
+SCHEMA_URIS: list[str] = [
     "https://stac-extensions.github.io/projection/v1.0.0/schema.json",
     SCHEMA_URI,
 ]
@@ -52,16 +62,18 @@ class ProjectionExtension(
        >>> proj_ext = ProjectionExtension.ext(item)
     """
 
+    name: Literal["proj"] = "proj"
+
     def apply(
         self,
-        epsg: Optional[int],
-        wkt2: Optional[str] = None,
-        projjson: Optional[Dict[str, Any]] = None,
-        geometry: Optional[Dict[str, Any]] = None,
-        bbox: Optional[List[float]] = None,
-        centroid: Optional[Dict[str, float]] = None,
-        shape: Optional[List[int]] = None,
-        transform: Optional[List[float]] = None,
+        epsg: int | None,
+        wkt2: str | None = None,
+        projjson: dict[str, Any] | None = None,
+        geometry: dict[str, Any] | None = None,
+        bbox: list[float] | None = None,
+        centroid: dict[str, float] | None = None,
+        shape: list[int] | None = None,
+        transform: list[float] | None = None,
     ) -> None:
         """Applies Projection extension properties to the extended Item.
 
@@ -95,7 +107,7 @@ class ProjectionExtension(
         self.transform = transform
 
     @property
-    def epsg(self) -> Optional[int]:
+    def epsg(self) -> int | None:
         """Get or sets the EPSG code of the datasource.
 
         A Coordinate Reference System (CRS) is the data reference system (sometimes
@@ -109,11 +121,11 @@ class ProjectionExtension(
         return self._get_property(EPSG_PROP, int)
 
     @epsg.setter
-    def epsg(self, v: Optional[int]) -> None:
+    def epsg(self, v: int | None) -> None:
         self._set_property(EPSG_PROP, v, pop_if_none=False)
 
     @property
-    def wkt2(self) -> Optional[str]:
+    def wkt2(self) -> str | None:
         """Get or sets the WKT2 string representing the Coordinate Reference System
         (CRS) that the ``proj:geometry`` and ``proj:bbox`` fields represent
 
@@ -126,11 +138,11 @@ class ProjectionExtension(
         return self._get_property(WKT2_PROP, str)
 
     @wkt2.setter
-    def wkt2(self, v: Optional[str]) -> None:
+    def wkt2(self, v: str | None) -> None:
         self._set_property(WKT2_PROP, v)
 
     @property
-    def projjson(self) -> Optional[Dict[str, Any]]:
+    def projjson(self) -> dict[str, Any] | None:
         """Get or sets the PROJJSON string representing the Coordinate Reference System
         (CRS) that the ``proj:geometry`` and ``proj:bbox`` fields represent
 
@@ -144,14 +156,14 @@ class ProjectionExtension(
         The schema for this object can be found
         `here <https://proj.org/schemas/v0.2/projjson.schema.json>`_.
         """
-        return self._get_property(PROJJSON_PROP, Dict[str, Any])
+        return self._get_property(PROJJSON_PROP, dict[str, Any])
 
     @projjson.setter
-    def projjson(self, v: Optional[Dict[str, Any]]) -> None:
+    def projjson(self, v: dict[str, Any] | None) -> None:
         self._set_property(PROJJSON_PROP, v)
 
     @property
-    def crs_string(self) -> Optional[str]:
+    def crs_string(self) -> str | None:
         """Returns the coordinate reference system (CRS) string for the extension.
 
         This string can be used to feed, e.g., ``rasterio.crs.CRS.from_string``.
@@ -172,7 +184,7 @@ class ProjectionExtension(
             return None
 
     @property
-    def geometry(self) -> Optional[Dict[str, Any]]:
+    def geometry(self) -> dict[str, Any] | None:
         """Get or sets a Polygon GeoJSON dict representing the footprint of this item.
 
         This dict should be formatted according the Polygon object format specified in
@@ -182,14 +194,14 @@ class ProjectionExtension(
         Ideally, this will be represented by a Polygon with five coordinates, as the
         item in the asset data CRS should be a square aligned to the original CRS grid.
         """
-        return self._get_property(GEOM_PROP, Dict[str, Any])
+        return self._get_property(GEOM_PROP, dict[str, Any])
 
     @geometry.setter
-    def geometry(self, v: Optional[Dict[str, Any]]) -> None:
+    def geometry(self, v: dict[str, Any] | None) -> None:
         self._set_property(GEOM_PROP, v)
 
     @property
-    def bbox(self) -> Optional[List[float]]:
+    def bbox(self) -> list[float] | None:
         """Get or sets the bounding box of the assets represented by this item in the
         asset data CRS.
 
@@ -201,14 +213,14 @@ class ProjectionExtension(
         highest]``. The length of the array must be 2*n where n is the number of
         dimensions.
         """
-        return self._get_property(BBOX_PROP, List[float])
+        return self._get_property(BBOX_PROP, list[float])
 
     @bbox.setter
-    def bbox(self, v: Optional[List[float]]) -> None:
+    def bbox(self, v: list[float] | None) -> None:
         self._set_property(BBOX_PROP, v)
 
     @property
-    def centroid(self) -> Optional[Dict[str, float]]:
+    def centroid(self) -> dict[str, float] | None:
         """Get or sets coordinates representing the centroid of the item in the asset
         data CRS.
 
@@ -219,14 +231,14 @@ class ProjectionExtension(
 
             item.ext.proj.centroid = { 'lat': 0.0, 'lon': 0.0 }
         """
-        return self._get_property(CENTROID_PROP, Dict[str, float])
+        return self._get_property(CENTROID_PROP, dict[str, float])
 
     @centroid.setter
-    def centroid(self, v: Optional[Dict[str, float]]) -> None:
+    def centroid(self, v: dict[str, float] | None) -> None:
         self._set_property(CENTROID_PROP, v)
 
     @property
-    def shape(self) -> Optional[List[int]]:
+    def shape(self) -> list[int] | None:
         """Get or sets the number of pixels in Y and X directions for the default grid.
 
         The shape is an array of integers that represents the number of pixels in the
@@ -234,14 +246,14 @@ class ProjectionExtension(
         be specified in Y, X order. If the shape is defined in an item's properties it
         is used as the default shape for all assets that don't have an overriding shape.
         """
-        return self._get_property(SHAPE_PROP, List[int])
+        return self._get_property(SHAPE_PROP, list[int])
 
     @shape.setter
-    def shape(self, v: Optional[List[int]]) -> None:
+    def shape(self, v: list[int] | None) -> None:
         self._set_property(SHAPE_PROP, v)
 
     @property
-    def transform(self) -> Optional[List[float]]:
+    def transform(self) -> list[float] | None:
         """Get or sets the the affine transformation coefficients for the default grid.
 
         The transform is a linear mapping from pixel coordinate space (Pixel, Line) to
@@ -253,16 +265,24 @@ class ProjectionExtension(
         or the Rasterio `Transform <https://rasterio.readthedocs.io/en/stable/api\
 /rasterio.io.html#rasterio.io.BufferedDatasetWriter.transform>`_.
         """
-        return self._get_property(TRANSFORM_PROP, List[float])
+        return self._get_property(TRANSFORM_PROP, list[float])
 
     @transform.setter
-    def transform(self, v: Optional[List[float]]) -> None:
+    def transform(self, v: list[float] | None) -> None:
         self._set_property(TRANSFORM_PROP, v)
 
     @classmethod
     def get_schema_uri(cls) -> str:
         return SCHEMA_URI
 
+    @classmethod
+    def get_schema_uris(cls) -> list[str]:
+        warnings.warn(
+            "get_schema_uris is deprecated and will be removed in v2",
+            DeprecationWarning,
+        )
+        return SCHEMA_URIS
+
     @classmethod
     def ext(cls, obj: T, add_if_missing: bool = False) -> ProjectionExtension[T]:
         """Extends the given STAC Object with properties from the :stac-ext:`Projection
@@ -276,33 +296,25 @@ class ProjectionExtension(
             pystac.ExtensionTypeError : If an invalid object type is passed.
         """
         if isinstance(obj, pystac.Item):
-            cls.validate_has_extension(obj, add_if_missing)
+            cls.ensure_has_extension(obj, add_if_missing)
             return cast(ProjectionExtension[T], ItemProjectionExtension(obj))
         elif isinstance(obj, pystac.Asset):
-            cls.validate_owner_has_extension(obj, add_if_missing)
+            cls.ensure_owner_has_extension(obj, add_if_missing)
             return cast(ProjectionExtension[T], AssetProjectionExtension(obj))
+        elif isinstance(obj, item_assets.AssetDefinition):
+            cls.ensure_owner_has_extension(obj, add_if_missing)
+            return cast(ProjectionExtension[T], ItemAssetsProjectionExtension(obj))
         else:
-            raise pystac.ExtensionTypeError(
-                f"Projection extension does not apply to type '{type(obj).__name__}'"
-            )
+            raise pystac.ExtensionTypeError(cls._ext_error_message(obj))
 
     @classmethod
     def summaries(
         cls, obj: pystac.Collection, add_if_missing: bool = False
     ) -> SummariesProjectionExtension:
         """Returns the extended summaries object for the given collection."""
-        cls.validate_has_extension(obj, add_if_missing)
+        cls.ensure_has_extension(obj, add_if_missing)
         return SummariesProjectionExtension(obj)
 
-    @classmethod
-    def has_extension(cls, obj: Union[pystac.Item, pystac.Collection]) -> bool:
-        if isinstance(obj, pystac.Item) or isinstance(obj, pystac.Collection):
-            return obj.stac_extensions is not None and any(
-                uri in obj.stac_extensions for uri in SCHEMA_URIS
-            )
-        else:
-            return False
-
 
 class ItemProjectionExtension(ProjectionExtension[pystac.Item]):
     """A concrete implementation of :class:`ProjectionExtension` on an
@@ -316,7 +328,7 @@ class ItemProjectionExtension(ProjectionExtension[pystac.Item]):
     item: pystac.Item
     """The :class:`~pystac.Item` being extended."""
 
-    properties: Dict[str, Any]
+    properties: dict[str, Any]
     """The :class:`~pystac.Item` properties, including extension properties."""
 
     def __init__(self, item: pystac.Item):
@@ -324,7 +336,7 @@ class ItemProjectionExtension(ProjectionExtension[pystac.Item]):
         self.properties = item.properties
 
     def __repr__(self) -> str:
-        return "<ItemProjectionExtension Item id={}>".format(self.item.id)
+        return f"<ItemProjectionExtension Item id={self.item.id}>"
 
 
 class AssetProjectionExtension(ProjectionExtension[pystac.Asset]):
@@ -339,10 +351,10 @@ class AssetProjectionExtension(ProjectionExtension[pystac.Asset]):
     asset_href: str
     """The ``href`` value of the :class:`~pystac.Asset` being extended."""
 
-    properties: Dict[str, Any]
+    properties: dict[str, Any]
     """The :class:`~pystac.Asset` fields, including extension properties."""
 
-    additional_read_properties: Optional[Iterable[Dict[str, Any]]] = None
+    additional_read_properties: Iterable[dict[str, Any]] | None = None
     """If present, this will be a list containing 1 dictionary representing the
     properties of the owning :class:`~pystac.Item`."""
 
@@ -353,7 +365,16 @@ class AssetProjectionExtension(ProjectionExtension[pystac.Asset]):
             self.additional_read_properties = [asset.owner.properties]
 
     def __repr__(self) -> str:
-        return "<AssetProjectionExtension Asset href={}>".format(self.asset_href)
+        return f"<AssetProjectionExtension Asset href={self.asset_href}>"
+
+
+class ItemAssetsProjectionExtension(ProjectionExtension[item_assets.AssetDefinition]):
+    properties: dict[str, Any]
+    asset_defn: item_assets.AssetDefinition
+
+    def __init__(self, item_asset: item_assets.AssetDefinition):
+        self.asset_defn = item_asset
+        self.properties = item_asset.properties
 
 
 class SummariesProjectionExtension(SummariesExtension):
@@ -363,20 +384,24 @@ class SummariesProjectionExtension(SummariesExtension):
     """
 
     @property
-    def epsg(self) -> Optional[List[int]]:
+    def epsg(self) -> list[int] | None:
         """Get or sets the summary of :attr:`ProjectionExtension.epsg` values
         for this Collection.
         """
         return self.summaries.get_list(EPSG_PROP)
 
     @epsg.setter
-    def epsg(self, v: Optional[List[int]]) -> None:
+    def epsg(self, v: list[int] | None) -> None:
         self._set_summary(EPSG_PROP, v)
 
 
 class ProjectionExtensionHooks(ExtensionHooks):
     schema_uri: str = SCHEMA_URI
-    prev_extension_ids = {"proj", "projection"}
+    prev_extension_ids = {
+        "proj",
+        "projection",
+        *[uri for uri in SCHEMA_URIS if uri != SCHEMA_URI],
+    }
     stac_object_types = {pystac.STACObjectType.ITEM}
 
 
