@@ -2,14 +2,17 @@
 
 from __future__ import annotations
 
-from typing import Any, Dict, Generic, List, Optional, TypeVar, Union, cast
+from typing import Any, Generic, Literal, TypeVar, Union, cast
 
 import pystac
+from pystac.extensions import item_assets
 from pystac.extensions.base import ExtensionManagementMixin, PropertiesExtension
 from pystac.extensions.hooks import ExtensionHooks
 from pystac.utils import get_required
 
-T = TypeVar("T", pystac.Collection, pystac.Item, pystac.Asset)
+T = TypeVar(
+    "T", pystac.Collection, pystac.Item, pystac.Asset, item_assets.AssetDefinition
+)
 
 SCHEMA_URI = "https://stac-extensions.github.io/table/v1.2.0/schema.json"
 
@@ -33,9 +36,9 @@ TBL_DESCRIPTION_PROP = "description"
 class Column:
     """Object representing a column of a table."""
 
-    properties: Dict[str, Any]
+    properties: dict[str, Any]
 
-    def __init__(self, properties: Dict[str, Any]):
+    def __init__(self, properties: dict[str, Any]):
         self.properties = properties
 
     @property
@@ -50,42 +53,42 @@ class Column:
         self.properties[COL_NAME_PROP] = v
 
     @property
-    def description(self) -> Optional[str]:
+    def description(self) -> str | None:
         """Detailed multi-line description to explain the column. `CommonMark 0.29
         <http://commonmark.org/>`__ syntax MAY be used for rich text representation."""
         return self.properties.get(COL_DESCRIPTION_PROP)
 
     @description.setter
-    def description(self, v: Optional[str]) -> None:
+    def description(self, v: str | None) -> None:
         if v is None:
             self.properties.pop(COL_DESCRIPTION_PROP, None)
         else:
             self.properties[COL_DESCRIPTION_PROP] = v
 
     @property
-    def col_type(self) -> Optional[str]:
+    def col_type(self) -> str | None:
         """Data type of the column. If using a file format with a type system (like
         Parquet), we recommend you use those types"""
         return self.properties.get(COL_TYPE_PROP)
 
     @col_type.setter
-    def col_type(self, v: Optional[str]) -> None:
+    def col_type(self, v: str | None) -> None:
         if v is None:
             self.properties.pop(COL_TYPE_PROP, None)
         else:
             self.properties[COL_TYPE_PROP] = v
 
-    def to_dict(self) -> Dict[str, Any]:
-        """Returns a JSON-like dictionary representing this ``Column``."""
+    def to_dict(self) -> dict[str, Any]:
+        """Returns a dictionary representing this ``Column``."""
         return self.properties
 
 
 class Table:
     """Object containing a high-level summary about a table"""
 
-    properties: Dict[str, Any]
+    properties: dict[str, Any]
 
-    def __init__(self, properties: Dict[str, Any]):
+    def __init__(self, properties: dict[str, Any]):
         self.properties = properties
 
     @property
@@ -98,20 +101,20 @@ class Table:
         self.properties[COL_NAME_PROP] = v
 
     @property
-    def description(self) -> Optional[str]:
+    def description(self) -> str | None:
         """Detailed multi-line description to explain the table. `CommonMark 0.29
         <http://commonmark.org/>`__ syntax MAY be used for rich text representation."""
         return self.properties.get(COL_DESCRIPTION_PROP)
 
     @description.setter
-    def description(self, v: Optional[str]) -> None:
+    def description(self, v: str | None) -> None:
         if v is None:
             self.properties.pop(COL_DESCRIPTION_PROP, None)
         else:
             self.properties[COL_DESCRIPTION_PROP] = v
 
-    def to_dict(self) -> Dict[str, Any]:
-        """Returns a JSON-like dictionary representing this ``Table``."""
+    def to_dict(self) -> dict[str, Any]:
+        """Returns a dictionary representing this ``Table``."""
         return self.properties
 
 
@@ -136,6 +139,8 @@ class TableExtension(
 
     """
 
+    name: Literal["table"] = "table"
+
     @classmethod
     def get_schema_uri(cls) -> str:
         return SCHEMA_URI
@@ -152,21 +157,22 @@ class TableExtension(
             pystac.ExtensionTypeError : If an invalid object type is passed.
         """
         if isinstance(obj, pystac.Collection):
-            cls.validate_has_extension(obj, add_if_missing)
+            cls.ensure_has_extension(obj, add_if_missing)
             return cast(TableExtension[T], CollectionTableExtension(obj))
         if isinstance(obj, pystac.Item):
-            cls.validate_has_extension(obj, add_if_missing)
+            cls.ensure_has_extension(obj, add_if_missing)
             return cast(TableExtension[T], ItemTableExtension(obj))
         if isinstance(obj, pystac.Asset):
-            cls.validate_owner_has_extension(obj, add_if_missing)
+            cls.ensure_owner_has_extension(obj, add_if_missing)
             return cast(TableExtension[T], AssetTableExtension(obj))
+        elif isinstance(obj, item_assets.AssetDefinition):
+            cls.ensure_owner_has_extension(obj, add_if_missing)
+            return cast(TableExtension[T], ItemAssetsTableExtension(obj))
         else:
-            raise pystac.ExtensionTypeError(
-                f"Table extension does not apply to type '{type(obj).__name__}'"
-            )
+            raise pystac.ExtensionTypeError(cls._ext_error_message(obj))
 
     @property
-    def columns(self) -> Optional[List[Column]]:
+    def columns(self) -> list[Column] | None:
         """A list of :class:`Column` objects describing each column"""
         v = self.properties.get(COLUMNS_PROP)
         if v is None:
@@ -174,28 +180,28 @@ class TableExtension(
         return [Column(x) for x in v]
 
     @columns.setter
-    def columns(self, v: Optional[List[Column]]) -> None:
+    def columns(self, v: list[Column] | None) -> None:
         self._set_property(COLUMNS_PROP, v)
 
     @property
-    def primary_geometry(self) -> Optional[str]:
+    def primary_geometry(self) -> str | None:
         """The primary geometry column name"""
         return self._get_property(PRIMARY_GEOMETRY_PROP, str)
 
     @primary_geometry.setter
-    def primary_geometry(self, v: Optional[str]) -> None:
+    def primary_geometry(self, v: str | None) -> None:
         if v is None:
             self.properties.pop(PRIMARY_GEOMETRY_PROP, None)
         else:
             self.properties[PRIMARY_GEOMETRY_PROP] = v
 
     @property
-    def row_count(self) -> Optional[int]:
+    def row_count(self) -> int | None:
         """The number of rows in the dataset"""
         return self._get_property(ROW_COUNT_PROP, int)
 
     @row_count.setter
-    def row_count(self, v: Optional[int]) -> None:
+    def row_count(self, v: int | None) -> None:
         if v is None:
             self.properties.pop(ROW_COUNT_PROP, None)
         else:
@@ -212,23 +218,23 @@ class CollectionTableExtension(TableExtension[pystac.Collection]):
     """
 
     collection: pystac.Collection
-    properties: Dict[str, Any]
+    properties: dict[str, Any]
 
     def __init__(self, collection: pystac.Collection):
         self.collection = collection
         self.properties = collection.extra_fields
 
     @property
-    def tables(self) -> Dict[str, Table]:
+    def tables(self) -> dict[str, Table]:
         """A mapping of table names to table objects"""
         return get_required(self.properties.get(TABLES_PROP), self, TABLES_PROP)
 
     @tables.setter
-    def tables(self, v: Dict[str, Table]) -> None:
+    def tables(self, v: dict[str, Table]) -> None:
         self.properties[TABLES_PROP] = v
 
     def __repr__(self) -> str:
-        return "<CollectionTableExtension Item id={}>".format(self.collection.id)
+        return f"<CollectionTableExtension Item id={self.collection.id}>"
 
 
 class ItemTableExtension(TableExtension[pystac.Item]):
@@ -241,14 +247,14 @@ class ItemTableExtension(TableExtension[pystac.Item]):
     """
 
     item: pystac.Item
-    properties: Dict[str, Any]
+    properties: dict[str, Any]
 
     def __init__(self, item: pystac.Item):
         self.item = item
         self.properties = item.properties
 
     def __repr__(self) -> str:
-        return "<ItemTableExtension Item id={}>".format(self.item.id)
+        return f"<ItemTableExtension Item id={self.item.id}>"
 
 
 class AssetTableExtension(TableExtension[pystac.Asset]):
@@ -261,8 +267,8 @@ class AssetTableExtension(TableExtension[pystac.Asset]):
     """
 
     asset_href: str
-    properties: Dict[str, Any]
-    additional_read_properties: Optional[List[Dict[str, Any]]]
+    properties: dict[str, Any]
+    additional_read_properties: list[dict[str, Any]] | None
 
     def __init__(self, asset: pystac.Asset):
         self.asset_href = asset.href
@@ -273,24 +279,38 @@ class AssetTableExtension(TableExtension[pystac.Asset]):
             self.additional_read_properties = None
 
     @property
-    def storage_options(self) -> Optional[Dict[str, Any]]:
+    def storage_options(self) -> dict[str, Any] | None:
         """Additional keywords for opening the dataset"""
         return self.properties.get(STORAGE_OPTIONS_PROP)
 
     @storage_options.setter
-    def storage_options(self, v: Optional[Dict[str, Any]]) -> Any:
+    def storage_options(self, v: dict[str, Any] | None) -> Any:
         if v is None:
             self.properties.pop(STORAGE_OPTIONS_PROP, None)
         else:
             self.properties[STORAGE_OPTIONS_PROP] = v
 
     def __repr__(self) -> str:
-        return "<AssetTableExtension Item id={}>".format(self.asset_href)
+        return f"<AssetTableExtension Item id={self.asset_href}>"
+
+
+class ItemAssetsTableExtension(TableExtension[item_assets.AssetDefinition]):
+    properties: dict[str, Any]
+    asset_defn: item_assets.AssetDefinition
+
+    def __init__(self, item_asset: item_assets.AssetDefinition):
+        self.asset_defn = item_asset
+        self.properties = item_asset.properties
 
 
 class TableExtensinoHooks(ExtensionHooks):
     schema_uri: str = SCHEMA_URI
-    prev_extension_ids = {"table"}
+    prev_extension_ids = {
+        "table",
+        "https://stac-extensions.github.io/table/v1.0.0/schema.json",
+        "https://stac-extensions.github.io/table/v1.0.1/schema.json",
+        "https://stac-extensions.github.io/table/v1.1.0/schema.json",
+    }
     stac_object_types = {pystac.STACObjectType.COLLECTION, pystac.STACObjectType.ITEM}
 
 
