@@ -1,8 +1,7 @@
 from functools import lru_cache
-from itertools import islice
 
 
-@lru_cache()
+@lru_cache
 def get_jinja_env():  # type: ignore
     try:
         from jinja2 import Environment, PackageLoader, select_autoescape
@@ -13,7 +12,4 @@ def get_jinja_env():  # type: ignore
         loader=PackageLoader("pystac", "html"), autoescape=select_autoescape()
     )
 
-    environment.filters["first"] = lambda x: islice(x, 1)
-    environment.filters["is_nonempty_generator"] = lambda x: next(x, None) is not None
-
     return environment
