@@ -1,11 +1,12 @@
 import json
 import logging
+import warnings
 from abc import ABC, abstractmethod
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Optional
 
 import pystac
 import pystac.utils
-from pystac.errors import STACLocalValidationError, STACValidationError
+from pystac.errors import STACValidationError
 from pystac.stac_object import STACObjectType
 from pystac.validation.schema_uri_map import DefaultSchemaUriMap, SchemaUriMap
 
@@ -13,8 +14,9 @@ try:
     import jsonschema
     import jsonschema.exceptions
     import jsonschema.validators
+    from referencing import Registry, Resource
 
-    from pystac.validation.local_validator import LocalValidator
+    from pystac.validation.local_validator import get_local_schema_cache
 
     HAS_JSONSCHEMA = True
 except ImportError:
@@ -23,6 +25,13 @@ except ImportError:
 logger = logging.getLogger(__name__)
 
 
+class GetSchemaError(Exception):
+    """Raised when unable to fetch a schema."""
+
+    def __init__(self, href: str, error: Exception) -> None:
+        super().__init__(f"Error when fetching schema {href}: {error}")
+
+
 class STACValidator(ABC):
     """STACValidator defines methods for validating STAC
     JSON. Implementations define methods for validating core objects and extension.
@@ -34,7 +43,7 @@ class STACValidator(ABC):
     @abstractmethod
     def validate_core(
         self,
-        stac_dict: Dict[str, Any],
+        stac_dict: dict[str, Any],
         stac_object_type: STACObjectType,
         stac_version: str,
         href: Optional[str] = None,
@@ -55,7 +64,7 @@ class STACValidator(ABC):
     @abstractmethod
     def validate_extension(
         self,
-        stac_dict: Dict[str, Any],
+        stac_dict: dict[str, Any],
         stac_object_type: STACObjectType,
         stac_version: str,
         extension_id: str,
@@ -77,12 +86,12 @@ class STACValidator(ABC):
 
     def validate(
         self,
-        stac_dict: Dict[str, Any],
+        stac_dict: dict[str, Any],
         stac_object_type: STACObjectType,
         stac_version: str,
-        extensions: List[str],
+        extensions: list[str],
         href: Optional[str] = None,
-    ) -> List[Any]:
+    ) -> list[Any]:
         """Validate a STAC object JSON.
 
         Args:
@@ -98,7 +107,7 @@ class STACValidator(ABC):
                core object and any extensions. Element type is specific to the
                STACValidator implementation.
         """
-        results: List[Any] = []
+        results: list[Any] = []
 
         # Pass the dict through JSON serialization and parsing, otherwise
         # some valid properties can be marked as invalid (e.g. tuples in
@@ -138,7 +147,7 @@ class JsonSchemaSTACValidator(STACValidator):
     """
 
     schema_uri_map: SchemaUriMap
-    schema_cache: Dict[str, Dict[str, Any]]
+    schema_cache: dict[str, dict[str, Any]]
 
     def __init__(self, schema_uri_map: Optional[SchemaUriMap] = None) -> None:
         if not HAS_JSONSCHEMA:
@@ -149,40 +158,54 @@ class JsonSchemaSTACValidator(STACValidator):
         else:
             self.schema_uri_map = DefaultSchemaUriMap()
 
-        self.schema_cache = {}
+        self.schema_cache = get_local_schema_cache()
 
-    def get_schema_from_uri(self, schema_uri: str) -> Tuple[Dict[str, Any], Any]:
+    def _get_schema(self, schema_uri: str) -> dict[str, Any]:
         if schema_uri not in self.schema_cache:
-            s = json.loads(pystac.StacIO.default().read_text(schema_uri))
+            try:
+                s = json.loads(pystac.StacIO.default().read_text(schema_uri))
+            except Exception as error:
+                raise GetSchemaError(schema_uri, error) from error
             self.schema_cache[schema_uri] = s
+            id_field = "$id" if "$id" in s else "id"
+            if not s[id_field].startswith("http"):
+                s[id_field] = schema_uri
+        return self.schema_cache[schema_uri]
 
-        schema = self.schema_cache[schema_uri]
+    @property
+    def registry(self) -> Any:
+        def retrieve(schema_uri: str) -> Resource[dict[str, Any]]:
+            return Resource.from_contents(self._get_schema(schema_uri))
 
-        resolver = jsonschema.validators.RefResolver(
-            base_uri=schema_uri, referrer=schema, store=self.schema_cache
+        return Registry(retrieve=retrieve).with_resources(  # type: ignore
+            [
+                (k, Resource.from_contents(v)) for k, v in self.schema_cache.items()
+            ]  # type: ignore
         )
 
-        return schema, resolver
+    def get_schema_from_uri(self, schema_uri: str) -> tuple[dict[str, Any], Any]:
+        """DEPRECATED"""
+        warnings.warn(
+            "get_schema_from_uri is deprecated and will be removed in v2.",
+            DeprecationWarning,
+        )
+        return self._get_schema(schema_uri), self.registry
 
     def _validate_from_uri(
         self,
-        stac_dict: Dict[str, Any],
+        stac_dict: dict[str, Any],
         stac_object_type: STACObjectType,
         schema_uri: str,
         href: Optional[str] = None,
     ) -> None:
         try:
-            resolver = None
-            try:
-                errors = LocalValidator()._validate_from_local(schema_uri, stac_dict)
-            except STACLocalValidationError:
-                schema, resolver = self.get_schema_from_uri(schema_uri)
-                # This block is cribbed (w/ change in error handling) from
-                # jsonschema.validate
-                cls = jsonschema.validators.validator_for(schema)
-                cls.check_schema(schema)
-                validator = cls(schema, resolver=resolver)
-                errors = list(validator.iter_errors(stac_dict))
+            schema = self._get_schema(schema_uri)
+            # This block is cribbed (w/ change in error handling) from
+            # jsonschema.validate
+            cls = jsonschema.validators.validator_for(schema)
+            cls.check_schema(schema)
+            validator = cls(schema, registry=self.registry)
+            errors = list(validator.iter_errors(stac_dict))
         except Exception as e:
             logger.error(f"Exception while validating {stac_object_type} href: {href}")
             logger.exception(e)
@@ -197,16 +220,13 @@ class JsonSchemaSTACValidator(STACValidator):
             msg += f"against schema at {schema_uri}"
 
             best = jsonschema.exceptions.best_match(errors)
+            if best:
+                msg += "\n" + str(best)
             raise STACValidationError(msg, source=errors) from best
 
-        if resolver is not None:
-            for uri in resolver.store:
-                if uri not in self.schema_cache:
-                    self.schema_cache[uri] = resolver.store[uri]
-
     def validate_core(
         self,
-        stac_dict: Dict[str, Any],
+        stac_dict: dict[str, Any],
         stac_object_type: STACObjectType,
         stac_version: str,
         href: Optional[str] = None,
@@ -245,7 +265,7 @@ class JsonSchemaSTACValidator(STACValidator):
 
     def validate_extension(
         self,
-        stac_dict: Dict[str, Any],
+        stac_dict: dict[str, Any],
         stac_object_type: STACObjectType,
         stac_version: str,
         extension_id: str,
