@@ -1,11 +1,11 @@
 import json
 import unittest
-from typing import Dict
 
 import pytest
 
 import pystac
 from pystac import ExtensionTypeError, Item
+from pystac.errors import ExtensionNotImplemented
 from pystac.extensions.eo import PREFIX, SNOW_COVER_PROP, Band, EOExtension
 from pystac.extensions.projection import ProjectionExtension
 from pystac.summaries import RangeSummary
@@ -57,7 +57,7 @@ class EOTest(unittest.TestCase):
     def test_to_from_dict(self) -> None:
         with open(self.LANDSAT_EXAMPLE_URI) as f:
             item_dict = json.load(f)
-        assert_to_from_dict(self, Item, item_dict)
+        assert_to_from_dict(Item, item_dict)
 
     def test_add_to(self) -> None:
         item = Item.from_file(self.PLAIN_ITEM)
@@ -234,14 +234,12 @@ class EOTest(unittest.TestCase):
     def test_summaries_adds_uri(self) -> None:
         col = pystac.Collection.from_file(self.EO_COLLECTION_URI)
         col.stac_extensions = []
-        self.assertRaisesRegex(
-            pystac.ExtensionNotImplemented,
-            r"Could not find extension schema URI.*",
-            EOExtension.summaries,
-            col,
-            False,
-        )
-        _ = EOExtension.summaries(col, add_if_missing=True)
+        with pytest.raises(
+            pystac.ExtensionNotImplemented, match="Extension 'eo' is not implemented"
+        ):
+            EOExtension.summaries(col, add_if_missing=False)
+
+        EOExtension.summaries(col, add_if_missing=True)
 
         self.assertIn(EOExtension.get_schema_uri(), col.stac_extensions)
 
@@ -459,7 +457,7 @@ def test_older_extension_version(ext_item: Item) -> None:
         ({"name": "B4", "common_name": "green"}, 0),
     ],
 )
-def test_get_assets(ext_item: pystac.Item, filter: Dict[str, str], count: int) -> None:
+def test_get_assets(ext_item: pystac.Item, filter: dict[str, str], count: int) -> None:
     assets = EOExtension.ext(ext_item).get_assets(**filter)  # type:ignore
     assert len(assets) == count
 
@@ -487,3 +485,22 @@ def test_exception_should_include_hint_if_obj_is_collection(
         match="Hint: Did you mean to use `EOExtension.summaries` instead?",
     ):
         EOExtension.ext(collection)  # type:ignore
+
+
+def test_ext_syntax(ext_item: pystac.Item) -> None:
+    assert ext_item.ext.eo.cloud_cover == 78
+    assert (bands := ext_item.assets["B1"].ext.eo.bands)
+    assert bands[0].name == "B1"
+
+
+def test_ext_syntax_remove(ext_item: pystac.Item) -> None:
+    ext_item.ext.remove("eo")
+    assert ext_item.ext.has("eo") is False
+    with pytest.raises(ExtensionNotImplemented):
+        ext_item.ext.eo
+
+
+def test_ext_syntax_add(item: pystac.Item) -> None:
+    item.ext.add("eo")
+    assert item.ext.has("eo") is True
+    assert isinstance(item.ext.eo, EOExtension)
