@@ -1,12 +1,13 @@
 import json
 import unittest
 from copy import deepcopy
-from typing import Any, Dict
+from typing import Any
 
 import pytest
 
 import pystac
 from pystac import ExtensionTypeError, Item
+from pystac.errors import ExtensionNotImplemented
 from pystac.extensions.projection import ProjectionExtension
 from pystac.utils import get_opt
 from tests.utils import TestCases, assert_to_from_dict
@@ -83,7 +84,7 @@ class ProjectionTest(unittest.TestCase):
     def test_to_from_dict(self) -> None:
         with open(self.example_uri) as f:
             d = json.load(f)
-        assert_to_from_dict(self, pystac.Item, d)
+        assert_to_from_dict(pystac.Item, d)
 
     def test_apply(self) -> None:
         item = next(TestCases.case_2().get_items(recursive=True))
@@ -290,7 +291,7 @@ class ProjectionTest(unittest.TestCase):
         self.assertEqual(asset_prop_geometry["coordinates"][0][0], [0.0, 0.0])
 
         # Set to Asset
-        asset_value: Dict[str, Any] = {"type": "Point", "coordinates": [1.0, 2.0]}
+        asset_value: dict[str, Any] = {"type": "Point", "coordinates": [1.0, 2.0]}
         ProjectionExtension.ext(asset_no_prop).geometry = asset_value
         self.assertNotEqual(
             ProjectionExtension.ext(asset_no_prop).geometry,
@@ -535,14 +536,12 @@ class ProjectionSummariesTest(unittest.TestCase):
     def test_summaries_adds_uri(self) -> None:
         col = pystac.Collection.from_file(self.example_uri)
         col.stac_extensions = []
-        self.assertRaisesRegex(
-            pystac.ExtensionNotImplemented,
-            r"Could not find extension schema URI.*",
-            ProjectionExtension.summaries,
-            col,
-            False,
-        )
-        _ = ProjectionExtension.summaries(col, True)
+        with pytest.raises(
+            pystac.ExtensionNotImplemented, match="Extension 'proj' is not implemented"
+        ):
+            ProjectionExtension.summaries(col, add_if_missing=False)
+
+        ProjectionExtension.summaries(col, True)
 
         self.assertIn(ProjectionExtension.get_schema_uri(), col.stac_extensions)
 
@@ -552,10 +551,10 @@ class ProjectionSummariesTest(unittest.TestCase):
 
 def test_older_extension_version(projection_landsat8_item: Item) -> None:
     old = "https://stac-extensions.github.io/projection/v1.0.0/schema.json"
-    new = "https://stac-extensions.github.io/projection/v1.1.0/schema.json"
+    current = "https://stac-extensions.github.io/projection/v1.1.0/schema.json"
 
     stac_extensions = set(projection_landsat8_item.stac_extensions)
-    stac_extensions.remove(new)
+    stac_extensions.remove(current)
     stac_extensions.add(old)
     item_as_dict = projection_landsat8_item.to_dict(
         include_self_link=False, transform_hrefs=False
@@ -565,6 +564,44 @@ def test_older_extension_version(projection_landsat8_item: Item) -> None:
     assert ProjectionExtension.has_extension(item)
     assert old in item.stac_extensions
 
+    migrated_item = pystac.Item.from_dict(item_as_dict, migrate=True)
+    assert ProjectionExtension.has_extension(migrated_item)
+    assert current in migrated_item.stac_extensions
+
+
+def test_newer_extension_version(projection_landsat8_item: Item) -> None:
+    new = "https://stac-extensions.github.io/projection/v2.0.0/schema.json"
+    current = "https://stac-extensions.github.io/projection/v1.1.0/schema.json"
+
+    stac_extensions = set(projection_landsat8_item.stac_extensions)
+    stac_extensions.remove(current)
+    stac_extensions.add(new)
+    item_as_dict = projection_landsat8_item.to_dict(
+        include_self_link=False, transform_hrefs=False
+    )
+    item_as_dict["stac_extensions"] = list(stac_extensions)
+    item = Item.from_dict(item_as_dict)
+    assert ProjectionExtension.has_extension(item)
+    assert new in item.stac_extensions
+
     migrated_item = pystac.Item.from_dict(item_as_dict, migrate=True)
     assert ProjectionExtension.has_extension(migrated_item)
     assert new in migrated_item.stac_extensions
+
+
+def test_ext_syntax(projection_landsat8_item: pystac.Item) -> None:
+    ext_item = projection_landsat8_item
+    assert ext_item.ext.proj.epsg == 32614
+    assert ext_item.assets["B1"].ext.proj.epsg == 32614
+
+
+def test_ext_syntax_remove(projection_landsat8_item: pystac.Item) -> None:
+    ext_item = projection_landsat8_item
+    ext_item.ext.remove("proj")
+    with pytest.raises(ExtensionNotImplemented):
+        ext_item.ext.proj
+
+
+def test_ext_syntax_add(item: pystac.Item) -> None:
+    item.ext.add("proj")
+    assert isinstance(item.ext.proj, ProjectionExtension)
