@@ -2,7 +2,7 @@
 
 import unittest
 from datetime import datetime, timedelta
-from typing import List, Optional
+from typing import Optional
 
 import pytest
 
@@ -245,7 +245,7 @@ def make_collection() -> pystac.Collection:
     end = start + timedelta(5, 4, 3, 2, 1)
     bboxes = [[-180.0, -90.0, 180.0, 90.0]]
     spatial_extent = pystac.SpatialExtent(bboxes)
-    intervals: List[List[Optional[datetime]]] = [[start, end]]
+    intervals: list[list[Optional[datetime]]] = [[start, end]]
     temporal_extent = pystac.TemporalExtent(intervals)
     extent = pystac.Extent(spatial_extent, temporal_extent)
     collection = pystac.Collection(asset_id, "desc", extent)
@@ -481,13 +481,12 @@ class SummariesScientificTest(unittest.TestCase):
     def test_summaries_adds_uri(self) -> None:
         collection = self.collection.clone()
         collection.stac_extensions = []
-        self.assertRaisesRegex(
+        with pytest.raises(
             pystac.ExtensionNotImplemented,
-            r"Could not find extension schema URI.*",
-            ScientificExtension.summaries,
-            collection,
-            False,
-        )
+            match="Extension 'sci' is not implemented",
+        ):
+            ScientificExtension.summaries(collection, add_if_missing=False)
+
         _ = ScientificExtension.summaries(collection, True)
 
         self.assertIn(ScientificExtension.get_schema_uri(), collection.stac_extensions)
