@@ -4,9 +4,10 @@ import json
 import os
 import tempfile
 import unittest
+from collections.abc import Iterator
 from copy import deepcopy
 from datetime import datetime
-from typing import Any, Dict, Iterator, Optional
+from typing import Any
 
 import pytest
 from dateutil import tz
@@ -258,7 +259,7 @@ class CollectionTest(unittest.TestCase):
 
     def test_removing_optional_attributes(self) -> None:
         path = TestCases.get_path("data-files/collections/with-assets.json")
-        with open(path, "r") as file:
+        with open(path) as file:
             data = json.load(file)
         data["title"] = "dummy title"
         data["stac_extensions"] = ["dummy extension"]
@@ -380,6 +381,31 @@ class ExtentTest(unittest.TestCase):
 
         _ = TemporalExtent([[start_datetime, end_datetime]])
 
+    @pytest.mark.block_network()
+    def test_temporal_extent_allows_single_interval(self) -> None:
+        start_datetime = str_to_datetime("2022-01-01T00:00:00Z")
+        end_datetime = str_to_datetime("2022-01-31T23:59:59Z")
+
+        interval = [start_datetime, end_datetime]
+        temporal_extent = TemporalExtent(intervals=interval)  # type: ignore
+
+        self.assertEqual(temporal_extent.intervals, [interval])
+
+    @pytest.mark.block_network()
+    def test_temporal_extent_allows_single_interval_open_start(self) -> None:
+        end_datetime = str_to_datetime("2022-01-31T23:59:59Z")
+
+        interval = [None, end_datetime]
+        temporal_extent = TemporalExtent(intervals=interval)
+
+        self.assertEqual(temporal_extent.intervals, [interval])
+
+    @pytest.mark.block_network()
+    def test_temporal_extent_non_list_intervals_fails(self) -> None:
+        with pytest.raises(TypeError):
+            # Pass in non-list intervals
+            _ = TemporalExtent(intervals=1)  # type: ignore
+
     @pytest.mark.block_network()
     def test_spatial_allows_single_bbox(self) -> None:
         temporal_extent = TemporalExtent(intervals=[[TEST_DATETIME, None]])
@@ -398,6 +424,12 @@ class ExtentTest(unittest.TestCase):
 
         collection.validate()
 
+    @pytest.mark.block_network()
+    def test_spatial_extent_non_list_bboxes_fails(self) -> None:
+        with pytest.raises(TypeError):
+            # Pass in non-list bboxes
+            _ = SpatialExtent(bboxes=1)  # type: ignore
+
     def test_from_items(self) -> None:
         item1 = Item(
             id="test-item-1",
@@ -559,9 +591,9 @@ def test_custom_collection_from_dict(collection: Collection) -> None:
         @classmethod
         def from_dict(
             cls,
-            d: Dict[str, Any],
-            href: Optional[str] = None,
-            root: Optional[Catalog] = None,
+            d: dict[str, Any],
+            href: str | None = None,
+            root: Catalog | None = None,
             migrate: bool = False,
             preserve_dict: bool = True,
         ) -> CustomCollection:
@@ -660,3 +692,13 @@ def test_delete_asset_relative_no_self_link_fails(
     assert asset.href in str(e.value)
     assert name in collection.assets
     assert os.path.exists(href)
+
+
+def test_permissive_temporal_extent_deserialization(collection: Collection) -> None:
+    # https://github.com/stac-utils/pystac/issues/1221
+    collection_dict = collection.to_dict(include_self_link=False, transform_hrefs=False)
+    collection_dict["extent"]["temporal"]["interval"] = collection_dict["extent"][
+        "temporal"
+    ]["interval"][0]
+    with pytest.warns(UserWarning):
+        Collection.from_dict(collection_dict)
