@@ -6,14 +6,14 @@ import tempfile
 import unittest
 from copy import deepcopy
 from pathlib import Path
-from typing import Any, Dict, Optional
+from typing import Any
 
 import dateutil.relativedelta
 import pytest
 
 import pystac
 import pystac.serialization.common_properties
-from pystac import Asset, Catalog, Collection, Item, Link
+from pystac import Asset, Catalog, Collection, Item, Link, STACValidationError
 from pystac.utils import (
     datetime_to_str,
     get_opt,
@@ -26,10 +26,10 @@ from tests.utils import TestCases, assert_to_from_dict
 
 
 class ItemTest(unittest.TestCase):
-    def get_example_item_dict(self) -> Dict[str, Any]:
+    def get_example_item_dict(self) -> dict[str, Any]:
         m = TestCases.get_path("data-files/item/sample-item.json")
         with open(m) as f:
-            item_dict: Dict[str, Any] = json.load(f)
+            item_dict: dict[str, Any] = json.load(f)
         return item_dict
 
     def test_to_from_dict(self) -> None:
@@ -38,7 +38,7 @@ class ItemTest(unittest.TestCase):
         item_dict = self.get_example_item_dict()
         param_dict = deepcopy(item_dict)
 
-        assert_to_from_dict(self, Item, param_dict)
+        assert_to_from_dict(Item, param_dict)
         item = Item.from_dict(param_dict)
         self.assertEqual(item.id, "CS3-20160503_132131_05")
 
@@ -435,9 +435,9 @@ def test_custom_item_from_dict(item: Item) -> None:
         @classmethod
         def from_dict(
             cls,
-            d: Dict[str, Any],
-            href: Optional[str] = None,
-            root: Optional[Catalog] = None,
+            d: dict[str, Any],
+            href: str | None = None,
+            root: Catalog | None = None,
             migrate: bool = False,
             preserve_dict: bool = True,
         ) -> CustomItem:
@@ -488,7 +488,7 @@ def test_duplicate_self_links(tmp_path: Path, sample_item: pystac.Item) -> None:
     assert len(sample_item.get_links(rel="self")) == 1
     path = tmp_path / "item.json"
     sample_item.save_object(include_self_link=True, dest_href=str(path))
-    sample_item = Item.from_file(str(path))
+    sample_item = Item.from_file(path)
     assert len(sample_item.get_links(rel="self")) == 1
 
 
@@ -576,6 +576,7 @@ def test_delete_asset_relative_no_self_link_fails(tmp_asset: pystac.Asset) -> No
 
     assert href is not None
     assert item is not None
+    assert isinstance(item, pystac.Item)
 
     item.set_self_href(None)
 
@@ -630,3 +631,16 @@ def test_non_hierarchical_relative_link() -> None:
     assert a.target_in_hierarchy(b)
     assert root.target_in_hierarchy(next(b.get_items()))
     assert root.target_in_hierarchy(root)
+
+
+def test_pathlib() -> None:
+    # This works, but breaks mypy until we fix
+    # https://github.com/stac-utils/pystac/issues/1216
+    Item.from_file(Path(TestCases.get_path("data-files/item/sample-item.json")))
+
+
+def test_invalid_error_message(item: Item) -> None:
+    item.extra_fields["collection"] = "can't have a collection"
+    with pytest.raises(STACValidationError) as error:
+        item.validate()
+    assert "can't have a collection" in str(error.value)
