@@ -2,21 +2,21 @@ import socket
 import unittest
 from typing import Any
 
-from pystac.summaries import RangeSummary, Summaries, Summarizer
+from pystac.summaries import RangeSummary, Summaries, Summarizer, SummaryStrategy
 from tests.utils import TestCases
 
 
 class SummariesTest(unittest.TestCase):
     def test_summary(self) -> None:
         coll = TestCases.case_5()
-        summaries = Summarizer().summarize(coll.get_all_items())
+        summaries = Summarizer().summarize(coll.get_items(recursive=True))
         summaries_dict = summaries.to_dict()
         self.assertEqual(len(summaries_dict["eo:bands"]), 4)
         self.assertEqual(len(summaries_dict["proj:epsg"]), 1)
 
     def test_summary_limit(self) -> None:
         coll = TestCases.case_5()
-        summaries = Summarizer().summarize(coll.get_all_items())
+        summaries = Summarizer().summarize(coll.get_items(recursive=True))
         summaries.maxcount = 2
         summaries_dict = summaries.to_dict()
         self.assertIsNone(summaries_dict.get("eo:bands"))
@@ -25,7 +25,21 @@ class SummariesTest(unittest.TestCase):
     def test_summary_custom_fields_file(self) -> None:
         coll = TestCases.case_5()
         path = TestCases.get_path("data-files/summaries/fields_no_bands.json")
-        summaries = Summarizer(path).summarize(coll.get_all_items())
+        summaries = Summarizer(path).summarize(coll.get_items(recursive=True))
+        summaries_dict = summaries.to_dict()
+        self.assertIsNone(summaries_dict.get("eo:bands"))
+        self.assertEqual(len(summaries_dict["proj:epsg"]), 1)
+
+    def test_summary_custom_fields_dict(self) -> None:
+        coll = TestCases.case_5()
+        spec = {
+            "eo:bands": SummaryStrategy.DONT_SUMMARIZE,
+            "proj:epsg": SummaryStrategy.ARRAY,
+        }
+        obj = Summarizer(spec)
+        self.assertTrue("eo:bands" not in obj.summaryfields)
+        self.assertEqual(obj.summaryfields["proj:epsg"], SummaryStrategy.ARRAY)
+        summaries = obj.summarize(coll.get_items(recursive=True))
         summaries_dict = summaries.to_dict()
         self.assertIsNone(summaries_dict.get("eo:bands"))
         self.assertEqual(len(summaries_dict["proj:epsg"]), 1)
@@ -33,22 +47,22 @@ class SummariesTest(unittest.TestCase):
     def test_summary_wrong_custom_fields_file(self) -> None:
         coll = TestCases.case_5()
         with self.assertRaises(FileNotFoundError) as context:
-            Summarizer("wrong/path").summarize(coll.get_all_items())
+            Summarizer("wrong/path").summarize(coll.get_items(recursive=True))
         self.assertTrue("No such file or directory" in str(context.exception))
 
-    def test_cannot_open_fields_file(self) -> None:
+    def test_can_open_fields_file_even_with_no_nework(self) -> None:
         old_socket = socket.socket
+        try:
 
-        class no_network(socket.socket):
-            def __init__(self, *args: Any, **kwargs: Any):
-                raise Exception("Network call blocked")
+            class no_network(socket.socket):
+                def __init__(self, *args: Any, **kwargs: Any):
+                    raise Exception("Network call blocked")
 
-        socket.socket = no_network  # type:ignore
-
-        with self.assertRaises(Exception) as context:
+            socket.socket = no_network  # type:ignore
             Summarizer()
-        socket.socket = old_socket  # type:ignore
-        self.assertTrue("Could not read fields definition" in str(context.exception))
+        finally:
+            # even if this test fails, it should not break the whole test suite
+            socket.socket = old_socket  # type:ignore
 
     def test_summary_empty(self) -> None:
         summaries = Summaries.empty()
@@ -56,12 +70,12 @@ class SummariesTest(unittest.TestCase):
 
     def test_summary_not_empty(self) -> None:
         coll = TestCases.case_5()
-        summaries = Summarizer().summarize(coll.get_all_items())
+        summaries = Summarizer().summarize(coll.get_items(recursive=True))
         self.assertFalse(summaries.is_empty())
 
     def test_clone_summary(self) -> None:
         coll = TestCases.case_5()
-        summaries = Summarizer().summarize(coll.get_all_items())
+        summaries = Summarizer().summarize(coll.get_items(recursive=True))
         summaries_dict = summaries.to_dict()
         self.assertEqual(len(summaries_dict["eo:bands"]), 4)
         self.assertEqual(len(summaries_dict["proj:epsg"]), 1)
